package defaults
import "github.com/aws/aws-sdk-go-v2/aws/defaults"
Package defaults provides recommended configuration values for AWS SDKs and CLIs.
Index ¶
- func ResolveDefaultsModeAuto(region string, environment aws.RuntimeEnvironment) aws.DefaultsMode
- type Configuration
Functions ¶
func ResolveDefaultsModeAuto ¶
func ResolveDefaultsModeAuto(region string, environment aws.RuntimeEnvironment) aws.DefaultsMode
ResolveDefaultsModeAuto is used to determine the effective aws.DefaultsMode when the mode is set to aws.DefaultsModeAuto.
Types ¶
type Configuration ¶
type Configuration struct {
// RetryMode is the configuration's default retry mode API clients should
// use for constructing a Retryer.
RetryMode aws.RetryMode
// ConnectTimeout is the maximum amount of time a dial will wait for
// a connect to complete.
//
// See https://pkg.go.dev/net#Dialer.Timeout
ConnectTimeout *time.Duration
// TLSNegotiationTimeout specifies the maximum amount of time waiting to
// wait for a TLS handshake.
//
// See https://pkg.go.dev/net/http#Transport.TLSHandshakeTimeout
TLSNegotiationTimeout *time.Duration
}
Configuration is the set of SDK configuration options that are determined based on the configured DefaultsMode.
func GetModeConfiguration ¶
func GetModeConfiguration(mode aws.DefaultsMode) (Configuration, error)
GetModeConfiguration returns the default Configuration descriptor for the given mode.
Supports the following modes: cross-region, in-region, mobile, standard
func (*Configuration) GetConnectTimeout ¶
func (c *Configuration) GetConnectTimeout() (time.Duration, bool)
GetConnectTimeout returns the ConnectTimeout value, returns false if the value is not set.
func (*Configuration) GetTLSNegotiationTimeout ¶
func (c *Configuration) GetTLSNegotiationTimeout() (time.Duration, bool)
GetTLSNegotiationTimeout returns the TLSNegotiationTimeout value, returns false if the value is not set.
Source Files ¶
auto.go configuration.go defaults.go doc.go
- Version
- v1.41.2
- Published
- Feb 23, 2026
- Platform
- linux/amd64
- Imports
- 5 packages
- Last checked
- 1 hour ago –
Tools for package owners.