agentregistry

package module
v1.2.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 28, 2026 License: Apache-2.0 Imports: 38 Imported by: 0

Documentation

Overview

Package agentregistry provides the API client, operations, and parameter types for Agent Registry.

Agent Registry lets callers discover, list, and retrieve approved records published to a registry.

Index

Constants

const ServiceAPIVersion = "2025-12-01"
const ServiceID = "Agent Registry"

Variables

var TypeRegistry = &smithy.TypeRegistry{
	Entries: map[string]*smithy.TypeRegistryEntry{
		"com.amazonaws.agentregistry#AccessDeniedException": {
			Schema: schemas.AccessDeniedException,
			New:    func() any { return &types.AccessDeniedException{} },
		},
		"com.amazonaws.agentregistry#InternalServerException": {
			Schema: schemas.InternalServerException,
			New:    func() any { return &types.InternalServerException{} },
		},
		"com.amazonaws.agentregistry#ResourceNotFoundException": {
			Schema: schemas.ResourceNotFoundException,
			New:    func() any { return &types.ResourceNotFoundException{} },
		},
		"com.amazonaws.agentregistry#ThrottlingException": {
			Schema: schemas.ThrottlingException,
			New:    func() any { return &types.ThrottlingException{} },
		},
		"com.amazonaws.agentregistry#UnauthorizedException": {
			Schema: schemas.UnauthorizedException,
			New:    func() any { return &types.UnauthorizedException{} },
		},
		"com.amazonaws.agentregistry#ValidationException": {
			Schema: schemas.ValidationException,
			New:    func() any { return &types.ValidationException{} },
		},
	},
}

TypeRegistry is the type registry for this service.

Functions

func NewDefaultEndpointResolver

func NewDefaultEndpointResolver() *internalendpoints.Resolver

NewDefaultEndpointResolver constructs a new service endpoint resolver

func WithAPIOptions

func WithAPIOptions(optFns ...func(*middleware.Stack) error) func(*Options)

WithAPIOptions returns a functional option for setting the Client's APIOptions option.

func WithEndpointResolver deprecated

func WithEndpointResolver(v EndpointResolver) func(*Options)

Deprecated: EndpointResolver and WithEndpointResolver. Providing a value for this field will likely prevent you from using any endpoint-related service features released after the introduction of EndpointResolverV2 and BaseEndpoint.

To migrate an EndpointResolver implementation that uses a custom endpoint, set the client option BaseEndpoint instead.

func WithEndpointResolverV2

func WithEndpointResolverV2(v EndpointResolverV2) func(*Options)

WithEndpointResolverV2 returns a functional option for setting the Client's EndpointResolverV2 option.

func WithSigV4SigningName

func WithSigV4SigningName(name string) func(*Options)

WithSigV4SigningName applies an override to the authentication workflow to use the given signing name for SigV4-authenticated operations.

This is an advanced setting. The value here is FINAL, taking precedence over the resolved signing name from both auth scheme resolution and endpoint resolution.

func WithSigV4SigningRegion

func WithSigV4SigningRegion(region string) func(*Options)

WithSigV4SigningRegion applies an override to the authentication workflow to use the given signing region for SigV4-authenticated operations.

This is an advanced setting. The value here is FINAL, taking precedence over the resolved signing region from both auth scheme resolution and endpoint resolution.

Types

type AuthResolverParameters

type AuthResolverParameters struct {
	// The name of the operation being invoked.
	Operation string

	// The region in which the operation is being invoked.
	Region string
}

AuthResolverParameters contains the set of inputs necessary for auth scheme resolution.

type AuthSchemeResolver

type AuthSchemeResolver interface {
	ResolveAuthSchemes(context.Context, *AuthResolverParameters) ([]*smithyauth.Option, error)
}

AuthSchemeResolver returns a set of possible authentication options for an operation.

type BatchGetDiscoverableRegistryRecordInput

type BatchGetDiscoverableRegistryRecordInput struct {

	//  The registry-scoped groups of record IDs to retrieve. Currently, you can
	// specify exactly one entry.
	//
	// This member is required.
	Entries []types.RegistryRecordsEntry
	// contains filtered or unexported fields
}

func (*BatchGetDiscoverableRegistryRecordInput) Serialize

func (*BatchGetDiscoverableRegistryRecordInput) SerializeMembers

type BatchGetDiscoverableRegistryRecordOutput

type BatchGetDiscoverableRegistryRecordOutput struct {

	//  The per-record errors for records that could not be retrieved. This list is
	// empty when all requested records were returned.
	//
	// This member is required.
	Errors []types.BatchGetDiscoverableRegistryRecordError

	//  The records that were successfully retrieved. Each record correlates to the
	// request by its recordId .
	//
	// This member is required.
	RegistryRecords []types.RegistryRecordSummary

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata
	// contains filtered or unexported fields
}

func (*BatchGetDiscoverableRegistryRecordOutput) Deserialize

func (*BatchGetDiscoverableRegistryRecordOutput) Serialize

func (*BatchGetDiscoverableRegistryRecordOutput) SerializeMembers

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client provides the API client to make operations call for Agent Registry.

func New

func New(options Options, optFns ...func(*Options)) *Client

New returns an initialized Client based on the functional options. Provide additional functional options to further configure the behavior of the client, such as changing the client's endpoint or adding custom middleware behavior.

func NewFromConfig

func NewFromConfig(cfg aws.Config, optFns ...func(*Options)) *Client

NewFromConfig returns a new client from the provided config.

func (*Client) BatchGetDiscoverableRegistryRecord

func (c *Client) BatchGetDiscoverableRegistryRecord(ctx context.Context, params *BatchGetDiscoverableRegistryRecordInput, optFns ...func(*Options)) (*BatchGetDiscoverableRegistryRecordOutput, error)
Retrieves multiple discoverable registry records by ID from a single registry.

Records that cannot be retrieved are reported individually in the errors list rather than failing the entire request.

func (*Client) ListDiscoverableRegistryRecords

func (c *Client) ListDiscoverableRegistryRecords(ctx context.Context, params *ListDiscoverableRegistryRecordsInput, optFns ...func(*Options)) (*ListDiscoverableRegistryRecordsOutput, error)
Lists the discoverable registry records in a registry. You can optionally

filter and paginate the results.

func (*Client) Options

func (c *Client) Options() Options

Options returns a copy of the client configuration.

Callers SHOULD NOT perform mutations on any inner structures within client config. Config overrides should instead be made on a per-operation basis through functional options.

func (*Client) SearchDiscoverableRegistryRecords

func (c *Client) SearchDiscoverableRegistryRecords(ctx context.Context, params *SearchDiscoverableRegistryRecordsInput, optFns ...func(*Options)) (*SearchDiscoverableRegistryRecordsOutput, error)
Searches the discoverable registry records in a registry using a natural

language query. Returns metadata for the matching records ordered by relevance.

type EndpointParameters

type EndpointParameters struct {
	// The AWS region of the service.
	//
	// Parameter is required.
	//
	// AWS::Region
	Region *string

	// Override the endpoint used to send requests.
	//
	// Parameter is
	// required.
	//
	// SDK::Endpoint
	Endpoint *string
}

EndpointParameters provides the parameters that influence how endpoints are resolved.

func (EndpointParameters) WithDefaults

func (p EndpointParameters) WithDefaults() EndpointParameters

WithDefaults returns a shallow copy of EndpointParameterswith default values applied to members where applicable.

type EndpointResolver

type EndpointResolver interface {
	ResolveEndpoint(region string, options EndpointResolverOptions) (aws.Endpoint, error)
}

EndpointResolver interface for resolving service endpoints.

func EndpointResolverFromURL

func EndpointResolverFromURL(url string, optFns ...func(*aws.Endpoint)) EndpointResolver

EndpointResolverFromURL returns an EndpointResolver configured using the provided endpoint url. By default, the resolved endpoint resolver uses the client region as signing region, and the endpoint source is set to EndpointSourceCustom.You can provide functional options to configure endpoint values for the resolved endpoint.

type EndpointResolverFunc

type EndpointResolverFunc func(region string, options EndpointResolverOptions) (aws.Endpoint, error)

EndpointResolverFunc is a helper utility that wraps a function so it satisfies the EndpointResolver interface. This is useful when you want to add additional endpoint resolving logic, or stub out specific endpoints with custom values.

func (EndpointResolverFunc) ResolveEndpoint

func (fn EndpointResolverFunc) ResolveEndpoint(region string, options EndpointResolverOptions) (endpoint aws.Endpoint, err error)

type EndpointResolverOptions

type EndpointResolverOptions = internalendpoints.Options

EndpointResolverOptions is the service endpoint resolver options

type EndpointResolverV2

type EndpointResolverV2 interface {
	ResolveEndpoint(ctx context.Context, params EndpointParameters) (
		smithyendpoints.Endpoint, error,
	)
}

EndpointResolverV2 provides the interface for resolving service endpoints.

func NewDefaultEndpointResolverV2

func NewDefaultEndpointResolverV2() EndpointResolverV2

type HTTPClient

type HTTPClient interface {
	Do(*http.Request) (*http.Response, error)
}

type HTTPSignerV4

type HTTPSignerV4 interface {
	SignHTTP(ctx context.Context, credentials aws.Credentials, r *http.Request, payloadHash string, service string, region string, signingTime time.Time, optFns ...func(*v4.SignerOptions)) error
}

type ListDiscoverableRegistryRecordsAPIClient

type ListDiscoverableRegistryRecordsAPIClient interface {
	ListDiscoverableRegistryRecords(context.Context, *ListDiscoverableRegistryRecordsInput, ...func(*Options)) (*ListDiscoverableRegistryRecordsOutput, error)
}

ListDiscoverableRegistryRecordsAPIClient is a client that implements the ListDiscoverableRegistryRecords operation.

type ListDiscoverableRegistryRecordsInput

type ListDiscoverableRegistryRecordsInput struct {

	// Registry identifier that accepts either ARN or ID format
	//
	// This member is required.
	RegistryId *string

	//  The filters to apply to the discoverable registry record list.
	Filters []types.RegistryRecordFilter

	//  The maximum number of records to return in a single page. Valid values are 1
	// through 100.
	MaxResults *int32

	//  The pagination token returned by a previous request. Use this value to
	// retrieve the next page of results.
	NextToken *string
	// contains filtered or unexported fields
}

func (*ListDiscoverableRegistryRecordsInput) Serialize

func (*ListDiscoverableRegistryRecordsInput) SerializeMembers

type ListDiscoverableRegistryRecordsOutput

type ListDiscoverableRegistryRecordsOutput struct {

	//  The page of discoverable registry record summaries.
	//
	// This member is required.
	RegistryRecords []types.DiscoverableRegistryRecordSummary

	//  The pagination token to pass to a subsequent request to retrieve the next page
	// of results. This field is absent when there are no more results.
	NextToken *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata
	// contains filtered or unexported fields
}

func (*ListDiscoverableRegistryRecordsOutput) Deserialize

func (*ListDiscoverableRegistryRecordsOutput) Serialize

func (*ListDiscoverableRegistryRecordsOutput) SerializeMembers

type ListDiscoverableRegistryRecordsPaginator

type ListDiscoverableRegistryRecordsPaginator struct {
	// contains filtered or unexported fields
}

ListDiscoverableRegistryRecordsPaginator is a paginator for ListDiscoverableRegistryRecords

func NewListDiscoverableRegistryRecordsPaginator

NewListDiscoverableRegistryRecordsPaginator returns a new ListDiscoverableRegistryRecordsPaginator

func (*ListDiscoverableRegistryRecordsPaginator) HasMorePages

HasMorePages returns a boolean indicating whether more pages are available

func (*ListDiscoverableRegistryRecordsPaginator) NextPage

NextPage retrieves the next ListDiscoverableRegistryRecords page.

type ListDiscoverableRegistryRecordsPaginatorOptions

type ListDiscoverableRegistryRecordsPaginatorOptions struct {
	//  The maximum number of records to return in a single page. Valid values are 1
	// through 100.
	Limit int32

	// Set to true if pagination should stop if the service returns a pagination token
	// that matches the most recent token provided to the service.
	StopOnDuplicateToken bool
}

ListDiscoverableRegistryRecordsPaginatorOptions is the paginator options for ListDiscoverableRegistryRecords

type Options

type Options struct {
	// Set of options to modify how an operation is invoked. These apply to all
	// operations invoked for this client. Use functional options on operation call to
	// modify this list for per operation behavior.
	APIOptions []func(*middleware.Stack) error

	// The optional application specific identifier appended to the User-Agent header.
	AppID string

	// This endpoint will be given as input to an EndpointResolverV2. It is used for
	// providing a custom base endpoint that is subject to modifications by the
	// processing EndpointResolverV2.
	BaseEndpoint *string

	// Configures the events that will be sent to the configured logger.
	ClientLogMode aws.ClientLogMode

	// The credentials object to use when signing requests.
	Credentials aws.CredentialsProvider

	// The configuration DefaultsMode that the SDK should use when constructing the
	// clients initial default settings.
	DefaultsMode aws.DefaultsMode

	// Disables SDK clock skew correction. When set, the SDK will not adjust request
	// signing timestamps to compensate for clock drift between the client and the
	// service.
	DisableClockSkewCorrection bool

	// The endpoint options to be used when attempting to resolve an endpoint.
	EndpointOptions EndpointResolverOptions

	// The service endpoint resolver.
	//
	// Deprecated: Deprecated: EndpointResolver and WithEndpointResolver. Providing a
	// value for this field will likely prevent you from using any endpoint-related
	// service features released after the introduction of EndpointResolverV2 and
	// BaseEndpoint.
	//
	// To migrate an EndpointResolver implementation that uses a custom endpoint, set
	// the client option BaseEndpoint instead.
	EndpointResolver EndpointResolver

	// Resolves the endpoint used for a particular service operation.
	EndpointResolverV2 EndpointResolverV2

	// Signature Version 4 (SigV4) Signer
	HTTPSignerV4 HTTPSignerV4

	// The logger writer interface to write logging messages to.
	Logger logging.Logger

	// The client meter provider.
	MeterProvider metrics.MeterProvider

	// The region to send requests to. (Required)
	Region string

	// RetryMaxAttempts specifies the maximum number attempts an API client will call
	// an operation that fails with a retryable error. A value of 0 is ignored, and
	// will not be used to configure the API client created default retryer, or modify
	// per operation call's retry max attempts.
	//
	// If specified in an operation call's functional options with a value that is
	// different than the constructed client's Options, the Client's Retryer will be
	// wrapped to use the operation's specific RetryMaxAttempts value.
	RetryMaxAttempts int

	// RetryMode specifies the retry mode the API client will be created with, if
	// Retryer option is not also specified.
	//
	// When creating a new API Clients this member will only be used if the Retryer
	// Options member is nil. This value will be ignored if Retryer is not nil.
	//
	// Currently does not support per operation call overrides, may in the future.
	RetryMode aws.RetryMode

	// Retryer guides how HTTP requests should be retried in case of recoverable
	// failures. When nil the API client will use a default retryer. The kind of
	// default retry created by the API client can be changed with the RetryMode
	// option.
	Retryer aws.Retryer

	// The RuntimeEnvironment configuration, only populated if the DefaultsMode is set
	// to DefaultsModeAuto and is initialized using config.LoadDefaultConfig . You
	// should not populate this structure programmatically, or rely on the values here
	// within your applications.
	RuntimeEnvironment aws.RuntimeEnvironment

	// The client tracer provider.
	TracerProvider tracing.TracerProvider

	Protocol smithyhttp.ClientProtocol

	// The HTTP client to invoke API calls with. Defaults to client's default HTTP
	// implementation if nil.
	HTTPClient HTTPClient

	// Client registry of operation interceptors.
	Interceptors smithyhttp.InterceptorRegistry

	// The auth scheme resolver which determines how to authenticate for each
	// operation.
	AuthSchemeResolver AuthSchemeResolver

	// The list of auth schemes supported by the client.
	AuthSchemes []smithyhttp.AuthScheme

	// Priority list of preferred auth scheme names (e.g. sigv4a).
	AuthSchemePreference []string
	// contains filtered or unexported fields
}

func (Options) Copy

func (o Options) Copy() Options

Copy creates a clone where the APIOptions list is deep copied.

func (Options) GetIdentityResolver

func (o Options) GetIdentityResolver(schemeID string) smithyauth.IdentityResolver

type ResolveEndpoint

type ResolveEndpoint struct {
	Resolver EndpointResolver
	Options  EndpointResolverOptions
}

func (*ResolveEndpoint) HandleSerialize

func (*ResolveEndpoint) ID

func (*ResolveEndpoint) ID() string

type SearchDiscoverableRegistryRecordsInput

type SearchDiscoverableRegistryRecordsInput struct {

	//  The registry identifiers to search within. Currently, you must specify exactly
	// one registry identifier. You can provide either the full Amazon Web Services
	// Resource Name (ARN) or the registry ID.
	//
	// This member is required.
	RegistryIds []string

	//  The natural language query to search for matching registry records.
	//
	// This member is required.
	SearchQuery *string

	//  An optional structured JSON metadata filter that narrows the search results.
	// Supports the field-level operators $eq , $ne , and $in , and the logical
	// operators $and and $or on filterable fields.
	Filters document.Interface

	//  The maximum number of results to return. Valid values are 1 through 20. The
	// default value is 10.
	MaxResults *int32
	// contains filtered or unexported fields
}

func (*SearchDiscoverableRegistryRecordsInput) Serialize

func (*SearchDiscoverableRegistryRecordsInput) SerializeMembers

type SearchDiscoverableRegistryRecordsOutput

type SearchDiscoverableRegistryRecordsOutput struct {

	//  The registry records that match the search query, ordered by relevance.
	//
	// This member is required.
	RegistryRecords []types.RegistryRecordSummary

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata
	// contains filtered or unexported fields
}

func (*SearchDiscoverableRegistryRecordsOutput) Deserialize

func (*SearchDiscoverableRegistryRecordsOutput) Serialize

func (*SearchDiscoverableRegistryRecordsOutput) SerializeMembers

Directories

Path Synopsis
Package document implements encoding and decoding of open-content that has a JSON-like data model.
Package document implements encoding and decoding of open-content that has a JSON-like data model.
internal

Jump to