types

package
v1.42.11 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 29, 2026 License: Apache-2.0 Imports: 4 Imported by: 13

Documentation

Index

Examples

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AccessDeniedException

type AccessDeniedException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

You do not have sufficient access to perform this action.

func (*AccessDeniedException) Error

func (e *AccessDeniedException) Error() string

func (*AccessDeniedException) ErrorCode

func (e *AccessDeniedException) ErrorCode() string

func (*AccessDeniedException) ErrorFault

func (e *AccessDeniedException) ErrorFault() smithy.ErrorFault

func (*AccessDeniedException) ErrorMessage

func (e *AccessDeniedException) ErrorMessage() string

type AlertManagerDefinitionDescription added in v1.6.0

type AlertManagerDefinitionDescription struct {

	// The date and time that the alert manager definition was created.
	//
	// This member is required.
	CreatedAt *time.Time

	// The actual alert manager definition.
	//
	// For details about the alert manager definition, see [AlertManagedDefinitionData].
	//
	// [AlertManagedDefinitionData]: https://docs.aws.amazon.com/prometheus/latest/APIReference/yaml-AlertManagerDefinitionData.html
	//
	// This member is required.
	Data []byte

	// The date and time that the alert manager definition was most recently changed.
	//
	// This member is required.
	ModifiedAt *time.Time

	// A structure that displays the current status of the alert manager definition..
	//
	// This member is required.
	Status *AlertManagerDefinitionStatus
	// contains filtered or unexported fields
}

The details of an alert manager definition. It is the configuration for the alert manager, including information about receivers for routing alerts.

type AlertManagerDefinitionStatus added in v1.6.0

type AlertManagerDefinitionStatus struct {

	// The current status of the alert manager.
	//
	// This member is required.
	StatusCode AlertManagerDefinitionStatusCode

	// If there is a failure, the reason for the failure.
	StatusReason *string
	// contains filtered or unexported fields
}

The status of the alert manager.

type AlertManagerDefinitionStatusCode added in v1.6.0

type AlertManagerDefinitionStatusCode string
const (
	// Definition is being created. Update/Deletion is disallowed until definition is
	// ACTIVE and workspace status is ACTIVE.
	AlertManagerDefinitionStatusCodeCreating AlertManagerDefinitionStatusCode = "CREATING"
	// Definition has been created/updated. Update/Deletion is disallowed until
	// definition is ACTIVE and workspace status is ACTIVE.
	AlertManagerDefinitionStatusCodeActive AlertManagerDefinitionStatusCode = "ACTIVE"
	// Definition is being updated. Update/Deletion is disallowed until definition is
	// ACTIVE and workspace status is ACTIVE.
	AlertManagerDefinitionStatusCodeUpdating AlertManagerDefinitionStatusCode = "UPDATING"
	// Definition is being deleting. Update/Deletion is disallowed until definition is
	// ACTIVE and workspace status is ACTIVE.
	AlertManagerDefinitionStatusCodeDeleting AlertManagerDefinitionStatusCode = "DELETING"
	// Definition creation failed.
	AlertManagerDefinitionStatusCodeCreationFailed AlertManagerDefinitionStatusCode = "CREATION_FAILED"
	// Definition update failed.
	AlertManagerDefinitionStatusCodeUpdateFailed AlertManagerDefinitionStatusCode = "UPDATE_FAILED"
)

Enum values for AlertManagerDefinitionStatusCode

func (AlertManagerDefinitionStatusCode) Values added in v1.6.0

Values returns all known values for AlertManagerDefinitionStatusCode. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type AmpConfiguration added in v1.20.0

type AmpConfiguration struct {

	// ARN of the Amazon Managed Service for Prometheus workspace.
	//
	// This member is required.
	WorkspaceArn *string
	// contains filtered or unexported fields
}

The AmpConfiguration structure defines the Amazon Managed Service for Prometheus instance a scraper should send metrics to.

type AnomalyDetectorConfiguration added in v1.41.0

type AnomalyDetectorConfiguration interface {
	// contains filtered or unexported methods
}

The configuration for the anomaly detection algorithm.

The following types satisfy this interface:

AnomalyDetectorConfigurationMemberRandomCutForest
Example (OutputUsage)
package main

import (
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/amp/types"
)

func main() {
	var union types.AnomalyDetectorConfiguration
	// type switches can be used to check the union value
	switch v := union.(type) {
	case *types.AnomalyDetectorConfigurationMemberRandomCutForest:
		_ = v.Value // Value is types.RandomCutForestConfiguration

	case *types.UnknownUnionMember:
		fmt.Println("unknown tag:", v.Tag)

	default:
		fmt.Println("union is nil or unknown type")

	}
}

type AnomalyDetectorConfigurationMemberRandomCutForest added in v1.41.0

type AnomalyDetectorConfigurationMemberRandomCutForest struct {
	Value RandomCutForestConfiguration
	// contains filtered or unexported fields
}

The Random Cut Forest algorithm configuration for anomaly detection.

type AnomalyDetectorDescription added in v1.41.0

type AnomalyDetectorDescription struct {

	// The user-friendly name of the anomaly detector.
	//
	// This member is required.
	Alias *string

	// The unique identifier of the anomaly detector.
	//
	// This member is required.
	AnomalyDetectorId *string

	// The Amazon Resource Name (ARN) of the anomaly detector.
	//
	// This member is required.
	Arn *string

	// The timestamp when the anomaly detector was created.
	//
	// This member is required.
	CreatedAt *time.Time

	// The timestamp when the anomaly detector was last modified.
	//
	// This member is required.
	ModifiedAt *time.Time

	// The current status of the anomaly detector.
	//
	// This member is required.
	Status *AnomalyDetectorStatus

	// The algorithm configuration of the anomaly detector.
	Configuration AnomalyDetectorConfiguration

	// The frequency, in seconds, at which the anomaly detector evaluates metrics.
	EvaluationIntervalInSeconds *int32

	// The Amazon Managed Service for Prometheus metric labels associated with the
	// anomaly detector.
	Labels map[string]string

	// The action taken when data is missing during evaluation.
	MissingDataAction AnomalyDetectorMissingDataAction

	// The tags applied to the anomaly detector.
	Tags map[string]string
	// contains filtered or unexported fields
}

Detailed information about an anomaly detector.

type AnomalyDetectorMissingDataAction added in v1.41.0

type AnomalyDetectorMissingDataAction interface {
	// contains filtered or unexported methods
}

Specifies the action to take when data is missing during anomaly detection evaluation.

The following types satisfy this interface:

AnomalyDetectorMissingDataActionMemberMarkAsAnomaly
AnomalyDetectorMissingDataActionMemberSkip
Example (OutputUsage)
package main

import (
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/amp/types"
)

func main() {
	var union types.AnomalyDetectorMissingDataAction
	// type switches can be used to check the union value
	switch v := union.(type) {
	case *types.AnomalyDetectorMissingDataActionMemberMarkAsAnomaly:
		_ = v.Value // Value is bool

	case *types.AnomalyDetectorMissingDataActionMemberSkip:
		_ = v.Value // Value is bool

	case *types.UnknownUnionMember:
		fmt.Println("unknown tag:", v.Tag)

	default:
		fmt.Println("union is nil or unknown type")

	}
}

type AnomalyDetectorMissingDataActionMemberMarkAsAnomaly added in v1.41.0

type AnomalyDetectorMissingDataActionMemberMarkAsAnomaly struct {
	Value bool
	// contains filtered or unexported fields
}

Marks missing data points as anomalies.

type AnomalyDetectorMissingDataActionMemberSkip added in v1.41.0

type AnomalyDetectorMissingDataActionMemberSkip struct {
	Value bool
	// contains filtered or unexported fields
}

Skips evaluation when data is missing.

type AnomalyDetectorStatus added in v1.41.0

type AnomalyDetectorStatus struct {

	// The status code of the anomaly detector.
	//
	// This member is required.
	StatusCode AnomalyDetectorStatusCode

	// A description of the current status of the anomaly detector.
	StatusReason *string
	// contains filtered or unexported fields
}

The status information of an anomaly detector.

type AnomalyDetectorStatusCode added in v1.41.0

type AnomalyDetectorStatusCode string
const (
	AnomalyDetectorStatusCodeCreating       AnomalyDetectorStatusCode = "CREATING"
	AnomalyDetectorStatusCodeActive         AnomalyDetectorStatusCode = "ACTIVE"
	AnomalyDetectorStatusCodeUpdating       AnomalyDetectorStatusCode = "UPDATING"
	AnomalyDetectorStatusCodeDeleting       AnomalyDetectorStatusCode = "DELETING"
	AnomalyDetectorStatusCodeCreationFailed AnomalyDetectorStatusCode = "CREATION_FAILED"
	AnomalyDetectorStatusCodeUpdateFailed   AnomalyDetectorStatusCode = "UPDATE_FAILED"
	AnomalyDetectorStatusCodeDeletionFailed AnomalyDetectorStatusCode = "DELETION_FAILED"
)

Enum values for AnomalyDetectorStatusCode

func (AnomalyDetectorStatusCode) Values added in v1.41.0

Values returns all known values for AnomalyDetectorStatusCode. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type AnomalyDetectorSummary added in v1.41.0

type AnomalyDetectorSummary struct {

	// The user-friendly name of the anomaly detector.
	//
	// This member is required.
	Alias *string

	// The unique identifier of the anomaly detector.
	//
	// This member is required.
	AnomalyDetectorId *string

	// The Amazon Resource Name (ARN) of the anomaly detector.
	//
	// This member is required.
	Arn *string

	// The timestamp when the anomaly detector was created.
	//
	// This member is required.
	CreatedAt *time.Time

	// The timestamp when the anomaly detector was last modified.
	//
	// This member is required.
	ModifiedAt *time.Time

	// The current status of the anomaly detector.
	//
	// This member is required.
	Status *AnomalyDetectorStatus

	// The tags applied to the anomaly detector.
	Tags map[string]string
	// contains filtered or unexported fields
}

Summary information about an anomaly detector for list operations.

type CloudWatchLogDestination added in v1.34.0

type CloudWatchLogDestination struct {

	// The ARN of the CloudWatch log group to which the vended log data will be
	// published. This log group must exist prior to calling this operation.
	//
	// This member is required.
	LogGroupArn *string
	// contains filtered or unexported fields
}

Configuration details for logging to CloudWatch Logs.

type ComponentConfig added in v1.40.0

type ComponentConfig struct {

	// Configuration options for the scraper component.
	Options map[string]string
	// contains filtered or unexported fields
}

Configuration settings for a scraper component.

type ConflictException

type ConflictException struct {
	Message *string

	ErrorCodeOverride *string

	ResourceId   *string
	ResourceType *string
	// contains filtered or unexported fields
}

The request would cause an inconsistent state.

func (*ConflictException) Error

func (e *ConflictException) Error() string

func (*ConflictException) ErrorCode

func (e *ConflictException) ErrorCode() string

func (*ConflictException) ErrorFault

func (e *ConflictException) ErrorFault() smithy.ErrorFault

func (*ConflictException) ErrorMessage

func (e *ConflictException) ErrorMessage() string

type Destination added in v1.20.0

type Destination interface {
	// contains filtered or unexported methods
}

Where to send the metrics from a scraper.

The following types satisfy this interface:

DestinationMemberAmpConfiguration
Example (OutputUsage)
package main

import (
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/amp/types"
)

func main() {
	var union types.Destination
	// type switches can be used to check the union value
	switch v := union.(type) {
	case *types.DestinationMemberAmpConfiguration:
		_ = v.Value // Value is types.AmpConfiguration

	case *types.UnknownUnionMember:
		fmt.Println("unknown tag:", v.Tag)

	default:
		fmt.Println("union is nil or unknown type")

	}
}

type DestinationMemberAmpConfiguration added in v1.20.0

type DestinationMemberAmpConfiguration struct {
	Value AmpConfiguration
	// contains filtered or unexported fields
}

The Amazon Managed Service for Prometheus workspace to send metrics to.

type EksConfiguration added in v1.20.0

type EksConfiguration struct {

	// ARN of the Amazon EKS cluster.
	//
	// This member is required.
	ClusterArn *string

	// A list of subnet IDs for the Amazon EKS cluster VPC configuration.
	//
	// This member is required.
	SubnetIds []string

	// A list of the security group IDs for the Amazon EKS cluster VPC configuration.
	SecurityGroupIds []string
	// contains filtered or unexported fields
}

The EksConfiguration structure describes the connection to the Amazon EKS cluster from which a scraper collects metrics.

type IgnoreNearExpected added in v1.41.0

type IgnoreNearExpected interface {
	// contains filtered or unexported methods
}

Configuration for threshold settings that determine when values near expected values should be ignored during anomaly detection.

The following types satisfy this interface:

IgnoreNearExpectedMemberAmount
IgnoreNearExpectedMemberRatio
Example (OutputUsage)
package main

import (
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/amp/types"
)

func main() {
	var union types.IgnoreNearExpected
	// type switches can be used to check the union value
	switch v := union.(type) {
	case *types.IgnoreNearExpectedMemberAmount:
		_ = v.Value // Value is float64

	case *types.IgnoreNearExpectedMemberRatio:
		_ = v.Value // Value is float64

	case *types.UnknownUnionMember:
		fmt.Println("unknown tag:", v.Tag)

	default:
		fmt.Println("union is nil or unknown type")

	}
}

type IgnoreNearExpectedMemberAmount added in v1.41.0

type IgnoreNearExpectedMemberAmount struct {
	Value float64
	// contains filtered or unexported fields
}

The absolute amount by which values can differ from expected values before being considered anomalous.

type IgnoreNearExpectedMemberRatio added in v1.41.0

type IgnoreNearExpectedMemberRatio struct {
	Value float64
	// contains filtered or unexported fields
}

The ratio by which values can differ from expected values before being considered anomalous.

type InternalServerException

type InternalServerException struct {
	Message *string

	ErrorCodeOverride *string

	RetryAfterSeconds *int32
	// contains filtered or unexported fields
}

An unexpected error occurred during the processing of the request.

func (*InternalServerException) Error

func (e *InternalServerException) Error() string

func (*InternalServerException) ErrorCode

func (e *InternalServerException) ErrorCode() string

func (*InternalServerException) ErrorFault

func (e *InternalServerException) ErrorFault() smithy.ErrorFault

func (*InternalServerException) ErrorMessage

func (e *InternalServerException) ErrorMessage() string

type LimitsPerLabelSet added in v1.33.0

type LimitsPerLabelSet struct {

	// This defines one label set that will have an enforced active time series limit.
	//
	// Label values accept ASCII characters and must contain at least one character
	// that isn't whitespace. ASCII control characters are not accepted. If the label
	// name is metric name label __name__ , then the metric part of the name must
	// conform to the following pattern: [a-zA-Z_:][a-zA-Z0-9_:]*
	//
	// This member is required.
	LabelSet map[string]string

	// This structure contains the information about the limits that apply to time
	// series that match this label set.
	//
	// This member is required.
	Limits *LimitsPerLabelSetEntry
	// contains filtered or unexported fields
}

This structure defines one label set used to enforce active time series limits for the workspace, and defines the limit for that label set.

A label set is a unique combination of label-value pairs. Use them to control time series limits and to monitor usage by specific label groups. Example label sets might be team:finance or env:prod

type LimitsPerLabelSetEntry added in v1.33.0

type LimitsPerLabelSetEntry struct {

	// The maximum number of active series that can be ingested that match this label
	// set.
	//
	// Setting this to 0 causes no label set limit to be enforced, but it does cause
	// Amazon Managed Service for Prometheus to vend label set metrics to CloudWatch
	MaxSeries *int64
	// contains filtered or unexported fields
}

This structure contains the information about the limits that apply to time series that match one label set.

type LoggingConfigurationMetadata added in v1.15.0

type LoggingConfigurationMetadata struct {

	// The date and time that the logging configuration was created.
	//
	// This member is required.
	CreatedAt *time.Time

	// The ARN of the CloudWatch log group to which the vended log data will be
	// published.
	//
	// This member is required.
	LogGroupArn *string

	// The date and time that the logging configuration was most recently changed.
	//
	// This member is required.
	ModifiedAt *time.Time

	// The current status of the logging configuration.
	//
	// This member is required.
	Status *LoggingConfigurationStatus

	// The ID of the workspace the logging configuration is for.
	//
	// This member is required.
	Workspace *string
	// contains filtered or unexported fields
}

Contains information about the current rules and alerting logging configuration for the workspace.

These logging configurations are only for rules and alerting logs.

type LoggingConfigurationStatus added in v1.15.0

type LoggingConfigurationStatus struct {

	// The current status of the current rules and alerting logging configuration.
	//
	// These logging configurations are only for rules and alerting logs.
	//
	// This member is required.
	StatusCode LoggingConfigurationStatusCode

	// If failed, the reason for the failure.
	StatusReason *string
	// contains filtered or unexported fields
}

The status of the logging configuration.

type LoggingConfigurationStatusCode added in v1.15.0

type LoggingConfigurationStatusCode string
const (
	// Logging configuration is being created. Update/Deletion is disallowed until
	// logging configuration is ACTIVE and workspace status is ACTIVE.
	LoggingConfigurationStatusCodeCreating LoggingConfigurationStatusCode = "CREATING"
	// Logging configuration has been created/updated. Update/Deletion is disallowed
	// until logging configuration is ACTIVE and workspace status is ACTIVE.
	LoggingConfigurationStatusCodeActive LoggingConfigurationStatusCode = "ACTIVE"
	// Logging configuration is being updated. Update/Deletion is disallowed until
	// logging configuration is ACTIVE and workspace status is ACTIVE.
	LoggingConfigurationStatusCodeUpdating LoggingConfigurationStatusCode = "UPDATING"
	// Logging configuration is being deleting. Update/Deletion is disallowed until
	// logging configuration is ACTIVE and workspace status is ACTIVE.
	LoggingConfigurationStatusCodeDeleting LoggingConfigurationStatusCode = "DELETING"
	// Logging configuration creation failed.
	LoggingConfigurationStatusCodeCreationFailed LoggingConfigurationStatusCode = "CREATION_FAILED"
	// Logging configuration update failed.
	LoggingConfigurationStatusCodeUpdateFailed LoggingConfigurationStatusCode = "UPDATE_FAILED"
)

Enum values for LoggingConfigurationStatusCode

func (LoggingConfigurationStatusCode) Values added in v1.15.0

Values returns all known values for LoggingConfigurationStatusCode. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type LoggingDestination added in v1.34.0

type LoggingDestination struct {

	// Configuration details for logging to CloudWatch Logs.
	//
	// This member is required.
	CloudWatchLogs *CloudWatchLogDestination

	// Filtering criteria that determine which queries are logged.
	//
	// This member is required.
	Filters *LoggingFilter
	// contains filtered or unexported fields
}

Defines a destination and its associated filtering criteria for query logging.

type LoggingFilter added in v1.34.0

type LoggingFilter struct {

	// The Query Samples Processed (QSP) threshold above which queries will be logged.
	// Queries processing more samples than this threshold will be captured in logs.
	//
	// This member is required.
	QspThreshold *int64
	// contains filtered or unexported fields
}

Filtering criteria that determine which queries are logged.

type QueryLoggingConfigurationMetadata added in v1.34.0

type QueryLoggingConfigurationMetadata struct {

	// The date and time when the query logging configuration was created.
	//
	// This member is required.
	CreatedAt *time.Time

	// The configured destinations for the query logging configuration.
	//
	// This member is required.
	Destinations []LoggingDestination

	// The date and time when the query logging configuration was last modified.
	//
	// This member is required.
	ModifiedAt *time.Time

	// The current status of the query logging configuration.
	//
	// This member is required.
	Status *QueryLoggingConfigurationStatus

	// The ID of the workspace associated with this query logging configuration.
	//
	// This member is required.
	Workspace *string
	// contains filtered or unexported fields
}

The metadata for a query logging configuration.

type QueryLoggingConfigurationStatus added in v1.34.0

type QueryLoggingConfigurationStatus struct {

	// The current status of the query logging configuration.
	//
	// This member is required.
	StatusCode QueryLoggingConfigurationStatusCode

	// If there is a failure, the reason for the failure.
	StatusReason *string
	// contains filtered or unexported fields
}

The status information for a query logging configuration.

type QueryLoggingConfigurationStatusCode added in v1.34.0

type QueryLoggingConfigurationStatusCode string
const (
	// Query logging configuration is being created.
	QueryLoggingConfigurationStatusCodeCreating QueryLoggingConfigurationStatusCode = "CREATING"
	// Query logging configuration is active.
	QueryLoggingConfigurationStatusCodeActive QueryLoggingConfigurationStatusCode = "ACTIVE"
	// Query logging configuration is being updated.
	QueryLoggingConfigurationStatusCodeUpdating QueryLoggingConfigurationStatusCode = "UPDATING"
	// Query logging configuration is being deleted.
	QueryLoggingConfigurationStatusCodeDeleting QueryLoggingConfigurationStatusCode = "DELETING"
	// Query logging configuration creation failed.
	QueryLoggingConfigurationStatusCodeCreationFailed QueryLoggingConfigurationStatusCode = "CREATION_FAILED"
	// Query logging configuration update failed.
	QueryLoggingConfigurationStatusCodeUpdateFailed QueryLoggingConfigurationStatusCode = "UPDATE_FAILED"
)

Enum values for QueryLoggingConfigurationStatusCode

func (QueryLoggingConfigurationStatusCode) Values added in v1.34.0

Values returns all known values for QueryLoggingConfigurationStatusCode. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type RandomCutForestConfiguration added in v1.41.0

type RandomCutForestConfiguration struct {

	// The Prometheus query used to retrieve the time-series data for anomaly
	// detection.
	//
	// Random Cut Forest queries must be wrapped by a supported PromQL aggregation
	// operator. For more information, see [Aggregation operators]on the Prometheus docs website.
	//
	// Supported PromQL aggregation operators: avg , count , group , max , min ,
	// quantile , stddev , stdvar , and sum .
	//
	// [Aggregation operators]: https://prometheus.io/docs/prometheus/latest/querying/operators/#aggregation-operators
	//
	// This member is required.
	Query *string

	// Configuration for ignoring values that are near expected values from above
	// during anomaly detection.
	IgnoreNearExpectedFromAbove IgnoreNearExpected

	// Configuration for ignoring values that are near expected values from below
	// during anomaly detection.
	IgnoreNearExpectedFromBelow IgnoreNearExpected

	// The number of data points sampled from the input stream for the Random Cut
	// Forest algorithm. The default number is 256 consecutive data points.
	SampleSize *int32

	// The number of consecutive data points used to create a shingle for the Random
	// Cut Forest algorithm. The default number is 8 consecutive data points.
	ShingleSize *int32
	// contains filtered or unexported fields
}

Configuration for the Random Cut Forest algorithm used for anomaly detection in time-series data.

type ResourceNotFoundException

type ResourceNotFoundException struct {
	Message *string

	ErrorCodeOverride *string

	ResourceId   *string
	ResourceType *string
	// contains filtered or unexported fields
}

The request references a resources that doesn't exist.

func (*ResourceNotFoundException) Error

func (e *ResourceNotFoundException) Error() string

func (*ResourceNotFoundException) ErrorCode

func (e *ResourceNotFoundException) ErrorCode() string

func (*ResourceNotFoundException) ErrorFault

func (*ResourceNotFoundException) ErrorMessage

func (e *ResourceNotFoundException) ErrorMessage() string

type RoleConfiguration added in v1.31.0

type RoleConfiguration struct {

	// The Amazon Resource Name (ARN) of the role used in the source account to enable
	// cross-account scraping. For information about the contents of this policy, see [Cross-account setup].
	//
	// [Cross-account setup]: https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-collector-how-to.html#cross-account-remote-write
	SourceRoleArn *string

	// The Amazon Resource Name (ARN) of the role used in the target account to enable
	// cross-account scraping. For information about the contents of this policy, see [Cross-account setup].
	//
	// [Cross-account setup]: https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-collector-how-to.html#cross-account-remote-write
	TargetRoleArn *string
	// contains filtered or unexported fields
}

Use this structure to enable cross-account access, so that you can use a target account to access Prometheus metrics from source accounts.

type RuleGroupsNamespaceDescription added in v1.6.0

type RuleGroupsNamespaceDescription struct {

	// The ARN of the rule groups namespace. For example,
	// arn:aws:aps:<region>:123456789012:rulegroupsnamespace/ws-example1-1234-abcd-5678-ef90abcd1234/rulesfile1
	// .
	//
	// This member is required.
	Arn *string

	// The date and time that the rule groups namespace was created.
	//
	// This member is required.
	CreatedAt *time.Time

	// The rule groups file used in the namespace.
	//
	// For details about the rule groups namespace structure, see [RuleGroupsNamespaceData].
	//
	// [RuleGroupsNamespaceData]: https://docs.aws.amazon.com/prometheus/latest/APIReference/yaml-RuleGroupsNamespaceData.html
	//
	// This member is required.
	Data []byte

	// The date and time that the rule groups namespace was most recently changed.
	//
	// This member is required.
	ModifiedAt *time.Time

	// The name of the rule groups namespace.
	//
	// This member is required.
	Name *string

	// The current status of the rule groups namespace.
	//
	// This member is required.
	Status *RuleGroupsNamespaceStatus

	// The list of tag keys and values that are associated with the rule groups
	// namespace.
	Tags map[string]string
	// contains filtered or unexported fields
}

The details about one rule groups namespace.

type RuleGroupsNamespaceStatus added in v1.6.0

type RuleGroupsNamespaceStatus struct {

	// The current status of the namespace.
	//
	// This member is required.
	StatusCode RuleGroupsNamespaceStatusCode

	// The reason for the failure, if any.
	StatusReason *string
	// contains filtered or unexported fields
}

The status information about a rule groups namespace.

type RuleGroupsNamespaceStatusCode added in v1.6.0

type RuleGroupsNamespaceStatusCode string
const (
	// Namespace is being created. Update/Deletion is disallowed until namespace is
	// ACTIVE and workspace status is ACTIVE.
	RuleGroupsNamespaceStatusCodeCreating RuleGroupsNamespaceStatusCode = "CREATING"
	// Namespace has been created/updated. Update/Deletion is disallowed until
	// namespace is ACTIVE and workspace status is ACTIVE.
	RuleGroupsNamespaceStatusCodeActive RuleGroupsNamespaceStatusCode = "ACTIVE"
	// Namespace is being updated. Update/Deletion is disallowed until namespace is
	// ACTIVE and workspace status is ACTIVE.
	RuleGroupsNamespaceStatusCodeUpdating RuleGroupsNamespaceStatusCode = "UPDATING"
	// Namespace is being deleting. Update/Deletion is disallowed until namespace is
	// ACTIVE and workspace status is ACTIVE.
	RuleGroupsNamespaceStatusCodeDeleting RuleGroupsNamespaceStatusCode = "DELETING"
	// Namespace creation failed.
	RuleGroupsNamespaceStatusCodeCreationFailed RuleGroupsNamespaceStatusCode = "CREATION_FAILED"
	// Namespace update failed.
	RuleGroupsNamespaceStatusCodeUpdateFailed RuleGroupsNamespaceStatusCode = "UPDATE_FAILED"
)

Enum values for RuleGroupsNamespaceStatusCode

func (RuleGroupsNamespaceStatusCode) Values added in v1.6.0

Values returns all known values for RuleGroupsNamespaceStatusCode. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type RuleGroupsNamespaceSummary added in v1.6.0

type RuleGroupsNamespaceSummary struct {

	// The ARN of the rule groups namespace.
	//
	// This member is required.
	Arn *string

	// The date and time that the rule groups namespace was created.
	//
	// This member is required.
	CreatedAt *time.Time

	// The date and time that the rule groups namespace was most recently changed.
	//
	// This member is required.
	ModifiedAt *time.Time

	// The name of the rule groups namespace.
	//
	// This member is required.
	Name *string

	// A structure that displays the current status of the rule groups namespace.
	//
	// This member is required.
	Status *RuleGroupsNamespaceStatus

	// The list of tag keys and values that are associated with the rule groups
	// namespace.
	Tags map[string]string
	// contains filtered or unexported fields
}

The high-level information about a rule groups namespace. To retrieve more information, use DescribeRuleGroupsNamespace .

type ScrapeConfiguration added in v1.20.0

type ScrapeConfiguration interface {
	// contains filtered or unexported methods
}

A scrape configuration for a scraper, base 64 encoded. For more information, see Scraper configurationin the Amazon Managed Service for Prometheus User Guide.

The following types satisfy this interface:

ScrapeConfigurationMemberConfigurationBlob
Example (OutputUsage)
package main

import (
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/amp/types"
)

func main() {
	var union types.ScrapeConfiguration
	// type switches can be used to check the union value
	switch v := union.(type) {
	case *types.ScrapeConfigurationMemberConfigurationBlob:
		_ = v.Value // Value is []byte

	case *types.UnknownUnionMember:
		fmt.Println("unknown tag:", v.Tag)

	default:
		fmt.Println("union is nil or unknown type")

	}
}

type ScrapeConfigurationMemberConfigurationBlob added in v1.20.0

type ScrapeConfigurationMemberConfigurationBlob struct {
	Value []byte
	// contains filtered or unexported fields
}

The base 64 encoded scrape configuration file.

type ScraperComponent added in v1.40.0

type ScraperComponent struct {

	// The type of the scraper component.
	//
	// This member is required.
	Type ScraperComponentType

	// The configuration settings for the scraper component.
	Config *ComponentConfig
	// contains filtered or unexported fields
}

A component of a Amazon Managed Service for Prometheus scraper that can be configured for logging.

type ScraperComponentType added in v1.40.0

type ScraperComponentType string
const (
	// Scraper service discoverer component
	ScraperComponentTypeServiceDiscovery ScraperComponentType = "SERVICE_DISCOVERY"
	// Scraper collector component
	ScraperComponentTypeCollector ScraperComponentType = "COLLECTOR"
	// Scraper exporter component
	ScraperComponentTypeExporter ScraperComponentType = "EXPORTER"
)

Enum values for ScraperComponentType

func (ScraperComponentType) Values added in v1.40.0

Values returns all known values for ScraperComponentType. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type ScraperDescription added in v1.20.0

type ScraperDescription struct {

	// The Amazon Resource Name (ARN) of the scraper. For example,
	// arn:aws:aps:<region>:123456798012:scraper/s-example1-1234-abcd-5678-ef9012abcd34
	// .
	//
	// This member is required.
	Arn *string

	// The date and time that the scraper was created.
	//
	// This member is required.
	CreatedAt *time.Time

	// The Amazon Managed Service for Prometheus workspace the scraper sends metrics
	// to.
	//
	// This member is required.
	Destination Destination

	// The date and time that the scraper was last modified.
	//
	// This member is required.
	LastModifiedAt *time.Time

	// The Amazon Resource Name (ARN) of the IAM role that provides permissions for
	// the scraper to discover and collect metrics on your behalf.
	//
	// For example,
	// arn:aws:iam::123456789012:role/service-role/AmazonGrafanaServiceRole-12example .
	//
	// This member is required.
	RoleArn *string

	// The configuration in use by the scraper.
	//
	// This member is required.
	ScrapeConfiguration ScrapeConfiguration

	// The ID of the scraper. For example, s-example1-1234-abcd-5678-ef9012abcd34 .
	//
	// This member is required.
	ScraperId *string

	// The Amazon EKS cluster from which the scraper collects metrics.
	//
	// This member is required.
	Source Source

	// A structure that contains the current status of the scraper.
	//
	// This member is required.
	Status *ScraperStatus

	// (Optional) A name associated with the scraper.
	Alias *string

	// This structure displays information about the IAM roles used for cross-account
	// scraping configuration.
	RoleConfiguration *RoleConfiguration

	// If there is a failure, the reason for the failure.
	StatusReason *string

	// (Optional) The list of tag keys and values associated with the scraper.
	Tags map[string]string
	// contains filtered or unexported fields
}

The ScraperDescription structure contains the full details about one scraper in your account.

type ScraperLoggingConfigurationStatus added in v1.40.0

type ScraperLoggingConfigurationStatus struct {

	// The status code of the scraper logging configuration.
	//
	// This member is required.
	StatusCode ScraperLoggingConfigurationStatusCode

	// The reason for the current status of the scraper logging configuration.
	StatusReason *string
	// contains filtered or unexported fields
}

The status of a scraper logging configuration.

type ScraperLoggingConfigurationStatusCode added in v1.40.0

type ScraperLoggingConfigurationStatusCode string
const (
	// Scraper logging configuration is being created.
	ScraperLoggingConfigurationStatusCodeCreating ScraperLoggingConfigurationStatusCode = "CREATING"
	// Scraper logging configuration is active.
	ScraperLoggingConfigurationStatusCodeActive ScraperLoggingConfigurationStatusCode = "ACTIVE"
	// Scraper logging configuration is being updated.
	ScraperLoggingConfigurationStatusCodeUpdating ScraperLoggingConfigurationStatusCode = "UPDATING"
	// Scraper logging configuration is being deleted.
	ScraperLoggingConfigurationStatusCodeDeleting ScraperLoggingConfigurationStatusCode = "DELETING"
	// Scraper logging configuration creation failed.
	ScraperLoggingConfigurationStatusCodeCreationFailed ScraperLoggingConfigurationStatusCode = "CREATION_FAILED"
	// Scraper logging configuration update failed.
	ScraperLoggingConfigurationStatusCodeUpdateFailed ScraperLoggingConfigurationStatusCode = "UPDATE_FAILED"
)

Enum values for ScraperLoggingConfigurationStatusCode

func (ScraperLoggingConfigurationStatusCode) Values added in v1.40.0

Values returns all known values for ScraperLoggingConfigurationStatusCode. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type ScraperLoggingDestination added in v1.40.0

type ScraperLoggingDestination interface {
	// contains filtered or unexported methods
}

The destination where scraper logs are sent.

The following types satisfy this interface:

ScraperLoggingDestinationMemberCloudWatchLogs
Example (OutputUsage)
package main

import (
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/amp/types"
)

func main() {
	var union types.ScraperLoggingDestination
	// type switches can be used to check the union value
	switch v := union.(type) {
	case *types.ScraperLoggingDestinationMemberCloudWatchLogs:
		_ = v.Value // Value is types.CloudWatchLogDestination

	case *types.UnknownUnionMember:
		fmt.Println("unknown tag:", v.Tag)

	default:
		fmt.Println("union is nil or unknown type")

	}
}

type ScraperLoggingDestinationMemberCloudWatchLogs added in v1.40.0

type ScraperLoggingDestinationMemberCloudWatchLogs struct {
	Value CloudWatchLogDestination
	// contains filtered or unexported fields
}

The CloudWatch Logs configuration for the scraper logging destination.

type ScraperStatus added in v1.20.0

type ScraperStatus struct {

	// The current status of the scraper.
	//
	// This member is required.
	StatusCode ScraperStatusCode
	// contains filtered or unexported fields
}

The ScraperStatus structure contains status information about the scraper.

type ScraperStatusCode added in v1.20.0

type ScraperStatusCode string
const (
	// Scraper is being created. Deletion is disallowed until status is ACTIVE.
	ScraperStatusCodeCreating ScraperStatusCode = "CREATING"
	// Scraper is being updated. Deletion is disallowed until status is ACTIVE.
	ScraperStatusCodeUpdating ScraperStatusCode = "UPDATING"
	// Scraper has been created and is usable.
	ScraperStatusCodeActive ScraperStatusCode = "ACTIVE"
	// Scraper is being deleted. Deletions are allowed only when status is ACTIVE.
	ScraperStatusCodeDeleting ScraperStatusCode = "DELETING"
	// Scraper creation failed.
	ScraperStatusCodeCreationFailed ScraperStatusCode = "CREATION_FAILED"
	// Scraper update failed.
	ScraperStatusCodeUpdateFailed ScraperStatusCode = "UPDATE_FAILED"
	// Scraper deletion failed.
	ScraperStatusCodeDeletionFailed ScraperStatusCode = "DELETION_FAILED"
)

Enum values for ScraperStatusCode

func (ScraperStatusCode) Values added in v1.20.0

Values returns all known values for ScraperStatusCode. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type ScraperSummary added in v1.20.0

type ScraperSummary struct {

	// The Amazon Resource Name (ARN) of the scraper.
	//
	// This member is required.
	Arn *string

	// The date and time that the scraper was created.
	//
	// This member is required.
	CreatedAt *time.Time

	// The Amazon Managed Service for Prometheus workspace the scraper sends metrics
	// to.
	//
	// This member is required.
	Destination Destination

	// The date and time that the scraper was last modified.
	//
	// This member is required.
	LastModifiedAt *time.Time

	// The Amazon Resource Name (ARN) of the IAM role that provides permissions for
	// the scraper to discover and collect metrics on your behalf.
	//
	// This member is required.
	RoleArn *string

	// The ID of the scraper.
	//
	// This member is required.
	ScraperId *string

	// The Amazon EKS cluster from which the scraper collects metrics.
	//
	// This member is required.
	Source Source

	// A structure that contains the current status of the scraper.
	//
	// This member is required.
	Status *ScraperStatus

	// (Optional) A name associated with the scraper.
	Alias *string

	// This structure displays information about the IAM roles used for cross-account
	// scraping configuration.
	RoleConfiguration *RoleConfiguration

	// If there is a failure, the reason for the failure.
	StatusReason *string

	// (Optional) The list of tag keys and values associated with the scraper.
	Tags map[string]string
	// contains filtered or unexported fields
}

The ScraperSummary structure contains a summary of the details about one scraper in your account.

type ServiceQuotaExceededException

type ServiceQuotaExceededException struct {
	Message *string

	ErrorCodeOverride *string

	ResourceId   *string
	ResourceType *string
	ServiceCode  *string
	QuotaCode    *string
	// contains filtered or unexported fields
}

Completing the request would cause a service quota to be exceeded.

func (*ServiceQuotaExceededException) Error

func (*ServiceQuotaExceededException) ErrorCode

func (e *ServiceQuotaExceededException) ErrorCode() string

func (*ServiceQuotaExceededException) ErrorFault

func (*ServiceQuotaExceededException) ErrorMessage

func (e *ServiceQuotaExceededException) ErrorMessage() string

type Source added in v1.20.0

type Source interface {
	// contains filtered or unexported methods
}

The source of collected metrics for a scraper.

The following types satisfy this interface:

SourceMemberEksConfiguration
SourceMemberVpcConfiguration
Example (OutputUsage)
package main

import (
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/amp/types"
)

func main() {
	var union types.Source
	// type switches can be used to check the union value
	switch v := union.(type) {
	case *types.SourceMemberEksConfiguration:
		_ = v.Value // Value is types.EksConfiguration

	case *types.SourceMemberVpcConfiguration:
		_ = v.Value // Value is types.VpcConfiguration

	case *types.UnknownUnionMember:
		fmt.Println("unknown tag:", v.Tag)

	default:
		fmt.Println("union is nil or unknown type")

	}
}

type SourceMemberEksConfiguration added in v1.20.0

type SourceMemberEksConfiguration struct {
	Value EksConfiguration
	// contains filtered or unexported fields
}

The Amazon EKS cluster from which a scraper collects metrics.

type SourceMemberVpcConfiguration added in v1.42.0

type SourceMemberVpcConfiguration struct {
	Value VpcConfiguration
	// contains filtered or unexported fields
}

The Amazon VPC configuration for the Prometheus collector when connecting to Amazon MSK clusters. This configuration enables secure, private network connectivity between the collector and your Amazon MSK cluster within your Amazon VPC.

type ThrottlingException

type ThrottlingException struct {
	Message *string

	ErrorCodeOverride *string

	ServiceCode       *string
	QuotaCode         *string
	RetryAfterSeconds *int32
	// contains filtered or unexported fields
}

The request was denied due to request throttling.

func (*ThrottlingException) Error

func (e *ThrottlingException) Error() string

func (*ThrottlingException) ErrorCode

func (e *ThrottlingException) ErrorCode() string

func (*ThrottlingException) ErrorFault

func (e *ThrottlingException) ErrorFault() smithy.ErrorFault

func (*ThrottlingException) ErrorMessage

func (e *ThrottlingException) ErrorMessage() string

type UnknownUnionMember added in v1.20.0

type UnknownUnionMember struct {
	Tag   string
	Value []byte
	// contains filtered or unexported fields
}

UnknownUnionMember is returned when a union member is returned over the wire, but has an unknown tag.

type ValidationException

type ValidationException struct {
	Message *string

	ErrorCodeOverride *string

	Reason    ValidationExceptionReason
	FieldList []ValidationExceptionField
	// contains filtered or unexported fields
}

The input fails to satisfy the constraints specified by an Amazon Web Services service.

func (*ValidationException) Error

func (e *ValidationException) Error() string

func (*ValidationException) ErrorCode

func (e *ValidationException) ErrorCode() string

func (*ValidationException) ErrorFault

func (e *ValidationException) ErrorFault() smithy.ErrorFault

func (*ValidationException) ErrorMessage

func (e *ValidationException) ErrorMessage() string

type ValidationExceptionField

type ValidationExceptionField struct {

	// A message describing why the field caused an exception.
	//
	// This member is required.
	Message *string

	// The name of the field that caused an exception.
	//
	// This member is required.
	Name *string
	// contains filtered or unexported fields
}

Information about a field passed into a request that resulted in an exception.

type ValidationExceptionReason

type ValidationExceptionReason string
const (
	ValidationExceptionReasonUnknownOperation      ValidationExceptionReason = "UNKNOWN_OPERATION"
	ValidationExceptionReasonCannotParse           ValidationExceptionReason = "CANNOT_PARSE"
	ValidationExceptionReasonFieldValidationFailed ValidationExceptionReason = "FIELD_VALIDATION_FAILED"
	ValidationExceptionReasonOther                 ValidationExceptionReason = "OTHER"
)

Enum values for ValidationExceptionReason

func (ValidationExceptionReason) Values

Values returns all known values for ValidationExceptionReason. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type VpcConfiguration added in v1.42.0

type VpcConfiguration struct {

	// The security group IDs that control network access for the Prometheus
	// collector. These security groups must allow the collector to communicate with
	// your Amazon MSK cluster on the required ports.
	//
	// This member is required.
	SecurityGroupIds []string

	// The subnet IDs where the Prometheus collector will be deployed. The subnets
	// must be in the same Amazon VPC as your Amazon MSK cluster and have network
	// connectivity to the cluster.
	//
	// This member is required.
	SubnetIds []string
	// contains filtered or unexported fields
}

The Amazon VPC configuration that specifies the network settings for a Prometheus collector to securely connect to Amazon MSK clusters. This configuration includes the security groups and subnets that control network access and placement for the collector.

type WorkspaceConfigurationDescription added in v1.33.0

type WorkspaceConfigurationDescription struct {

	// This structure displays the current status of the workspace configuration, and
	// might also contain a reason for that status.
	//
	// This member is required.
	Status *WorkspaceConfigurationStatus

	// This is an array of structures, where each structure displays one label sets
	// for the workspace and the limits for that label set.
	LimitsPerLabelSet []LimitsPerLabelSet

	// This field displays how many days that metrics are retained in the workspace.
	RetentionPeriodInDays *int32
	// contains filtered or unexported fields
}

This structure contains the description of the workspace configuration.

type WorkspaceConfigurationStatus added in v1.33.0

type WorkspaceConfigurationStatus struct {

	// The current status of the workspace configuration.
	//
	// This member is required.
	StatusCode WorkspaceConfigurationStatusCode

	// The reason for the current status, if a reason is available.
	StatusReason *string
	// contains filtered or unexported fields
}

This structure displays the current status of the workspace configuration, and might also contain a reason for that status.

type WorkspaceConfigurationStatusCode added in v1.33.0

type WorkspaceConfigurationStatusCode string
const (
	// Workspace configuration has been updated. Update is disallowed until workspace
	// configuration is ACTIVE and workspace status is ACTIVE.
	WorkspaceConfigurationStatusCodeActive WorkspaceConfigurationStatusCode = "ACTIVE"
	// Workspace configuration is being updated. Update is disallowed until workspace
	// configuration is ACTIVE and workspace status is ACTIVE.
	WorkspaceConfigurationStatusCodeUpdating WorkspaceConfigurationStatusCode = "UPDATING"
	// Workspace configuration update failed.
	WorkspaceConfigurationStatusCodeUpdateFailed WorkspaceConfigurationStatusCode = "UPDATE_FAILED"
)

Enum values for WorkspaceConfigurationStatusCode

func (WorkspaceConfigurationStatusCode) Values added in v1.33.0

Values returns all known values for WorkspaceConfigurationStatusCode. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type WorkspaceDescription

type WorkspaceDescription struct {

	// The ARN of the workspace. For example,
	// arn:aws:aps:<region>:123456789012:workspace/ws-example1-1234-abcd-5678-ef90abcd1234
	// .
	//
	// This member is required.
	Arn *string

	// The date and time that the workspace was created.
	//
	// This member is required.
	CreatedAt *time.Time

	// The current status of the workspace.
	//
	// This member is required.
	Status *WorkspaceStatus

	// The unique ID for the workspace. For example,
	// ws-example1-1234-abcd-5678-ef90abcd1234 .
	//
	// This member is required.
	WorkspaceId *string

	// The alias that is assigned to this workspace to help identify it. It does not
	// need to be unique.
	Alias *string

	// (optional) If the workspace was created with a customer managed KMS key, the
	// ARN for the key used.
	KmsKeyArn *string

	// The Prometheus endpoint available for this workspace. For example,
	// https://aps-workspaces.<region>.amazonaws.com/workspaces/ws-example1-1234-abcd-5678-ef90abcd1234/api/v1/
	// .
	PrometheusEndpoint *string

	// The list of tag keys and values that are associated with the workspace.
	Tags map[string]string
	// contains filtered or unexported fields
}

The full details about one Amazon Managed Service for Prometheus workspace in your account.

type WorkspacePolicyStatusCode added in v1.38.0

type WorkspacePolicyStatusCode string
const (
	// Resource-based Policy is being created. Update/Deletion is disallowed until
	// Resource-based Policy is ACTIVE and Workspace is ACTIVE.
	WorkspacePolicyStatusCodeCreating WorkspacePolicyStatusCode = "CREATING"
	// Resource-based Policy has been created/updated. Update/Deletion is disallowed
	// until Resource-based Policy is ACTIVE and Workspace is ACTIVE.
	WorkspacePolicyStatusCodeActive WorkspacePolicyStatusCode = "ACTIVE"
	// Resource-based Policy is being updated. Update/Deletion is disallowed until
	// Resource-based Policy is ACTIVE and Workspace is ACTIVE.
	WorkspacePolicyStatusCodeUpdating WorkspacePolicyStatusCode = "UPDATING"
	// Resource-based Policy is being deleting. Update/Deletion is disallowed until
	// Resource-based Policy is ACTIVE and Workspace is ACTIVE.
	WorkspacePolicyStatusCodeDeleting WorkspacePolicyStatusCode = "DELETING"
)

Enum values for WorkspacePolicyStatusCode

func (WorkspacePolicyStatusCode) Values added in v1.38.0

Values returns all known values for WorkspacePolicyStatusCode. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type WorkspaceStatus

type WorkspaceStatus struct {

	// The current status of the workspace.
	//
	// This member is required.
	StatusCode WorkspaceStatusCode
	// contains filtered or unexported fields
}

The status of the workspace.

type WorkspaceStatusCode

type WorkspaceStatusCode string
const (
	// Workspace is being created. Deletion is disallowed until status is ACTIVE.
	WorkspaceStatusCodeCreating WorkspaceStatusCode = "CREATING"
	// Workspace has been created and is usable.
	WorkspaceStatusCodeActive WorkspaceStatusCode = "ACTIVE"
	// Workspace is being updated. Updates are allowed only when status is ACTIVE.
	WorkspaceStatusCodeUpdating WorkspaceStatusCode = "UPDATING"
	// Workspace is being deleted. Deletions are allowed only when status is ACTIVE.
	WorkspaceStatusCodeDeleting WorkspaceStatusCode = "DELETING"
	// Workspace creation failed. Refer to WorkspaceStatus.failureReason for more
	// details.
	WorkspaceStatusCodeCreationFailed WorkspaceStatusCode = "CREATION_FAILED"
)

Enum values for WorkspaceStatusCode

func (WorkspaceStatusCode) Values

Values returns all known values for WorkspaceStatusCode. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type WorkspaceSummary

type WorkspaceSummary struct {

	// The ARN of the workspace.
	//
	// This member is required.
	Arn *string

	// The date and time that the workspace was created.
	//
	// This member is required.
	CreatedAt *time.Time

	// The current status of the workspace.
	//
	// This member is required.
	Status *WorkspaceStatus

	// The unique ID for the workspace.
	//
	// This member is required.
	WorkspaceId *string

	// The alias that is assigned to this workspace to help identify it. It does not
	// need to be unique.
	Alias *string

	// (optional) If the workspace was created with a customer managed KMS key, the
	// ARN for the key used.
	KmsKeyArn *string

	// The list of tag keys and values that are associated with the workspace.
	Tags map[string]string
	// contains filtered or unexported fields
}

The information about one Amazon Managed Service for Prometheus workspace in your account.

Jump to