package types
import "github.com/aws/aws-sdk-go-v2/service/iot1clickdevicesservice/types"
Index ¶
- type Attributes
- type Device
- type DeviceDescription
- type DeviceEvent
- type DeviceMethod
- type ForbiddenException
- func (e *ForbiddenException) Error() string
- func (e *ForbiddenException) ErrorCode() string
- func (e *ForbiddenException) ErrorFault() smithy.ErrorFault
- func (e *ForbiddenException) ErrorMessage() string
- type InternalFailureException
- func (e *InternalFailureException) Error() string
- func (e *InternalFailureException) ErrorCode() string
- func (e *InternalFailureException) ErrorFault() smithy.ErrorFault
- func (e *InternalFailureException) ErrorMessage() string
- type InvalidRequestException
- func (e *InvalidRequestException) Error() string
- func (e *InvalidRequestException) ErrorCode() string
- func (e *InvalidRequestException) ErrorFault() smithy.ErrorFault
- func (e *InvalidRequestException) ErrorMessage() string
- type PreconditionFailedException
- func (e *PreconditionFailedException) Error() string
- func (e *PreconditionFailedException) ErrorCode() string
- func (e *PreconditionFailedException) ErrorFault() smithy.ErrorFault
- func (e *PreconditionFailedException) ErrorMessage() string
- type RangeNotSatisfiableException
- func (e *RangeNotSatisfiableException) Error() string
- func (e *RangeNotSatisfiableException) ErrorCode() string
- func (e *RangeNotSatisfiableException) ErrorFault() smithy.ErrorFault
- func (e *RangeNotSatisfiableException) ErrorMessage() string
- type ResourceConflictException
- func (e *ResourceConflictException) Error() string
- func (e *ResourceConflictException) ErrorCode() string
- func (e *ResourceConflictException) ErrorFault() smithy.ErrorFault
- func (e *ResourceConflictException) ErrorMessage() string
- type ResourceNotFoundException
Types ¶
type Attributes ¶
type Attributes struct {
// contains filtered or unexported fields
}
type Device ¶
type Device struct {
// The user specified attributes associated with the device for an event.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
Attributes *Attributes
// The unique identifier of the device.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
DeviceId *string
// The device type, such as "button".
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
Type *string
// contains filtered or unexported fields
}
type DeviceDescription ¶
type DeviceDescription struct {
// The ARN of the device.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
Arn *string
// An array of zero or more elements of DeviceAttribute objects providing user
// specified device attributes.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
Attributes map[string]string
// The unique identifier of the device.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
DeviceId *string
// A Boolean value indicating whether or not the device is enabled.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
Enabled *bool
// A value between 0 and 1 inclusive, representing the fraction of life remaining
// for the device.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
RemainingLife *float64
// The tags currently associated with the AWS IoT 1-Click device.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
Tags map[string]string
// The type of the device, such as "button".
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
Type *string
// contains filtered or unexported fields
}
type DeviceEvent ¶
type DeviceEvent struct {
// An object representing the device associated with the event.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
Device *Device
// A serialized JSON object representing the device-type specific event.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
StdEvent *string
// contains filtered or unexported fields
}
type DeviceMethod ¶
type DeviceMethod struct {
// The type of the device, such as "button".
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
DeviceType *string
// The name of the method applicable to the deviceType.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
MethodName *string
// contains filtered or unexported fields
}
type ForbiddenException ¶
type ForbiddenException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
func (*ForbiddenException) Error ¶
func (e *ForbiddenException) Error() string
func (*ForbiddenException) ErrorCode ¶
func (e *ForbiddenException) ErrorCode() string
func (*ForbiddenException) ErrorFault ¶
func (e *ForbiddenException) ErrorFault() smithy.ErrorFault
func (*ForbiddenException) ErrorMessage ¶
func (e *ForbiddenException) ErrorMessage() string
type InternalFailureException ¶
type InternalFailureException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
func (*InternalFailureException) Error ¶
func (e *InternalFailureException) Error() string
func (*InternalFailureException) ErrorCode ¶
func (e *InternalFailureException) ErrorCode() string
func (*InternalFailureException) ErrorFault ¶
func (e *InternalFailureException) ErrorFault() smithy.ErrorFault
func (*InternalFailureException) ErrorMessage ¶
func (e *InternalFailureException) ErrorMessage() string
type InvalidRequestException ¶
type InvalidRequestException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
func (*InvalidRequestException) Error ¶
func (e *InvalidRequestException) Error() string
func (*InvalidRequestException) ErrorCode ¶
func (e *InvalidRequestException) ErrorCode() string
func (*InvalidRequestException) ErrorFault ¶
func (e *InvalidRequestException) ErrorFault() smithy.ErrorFault
func (*InvalidRequestException) ErrorMessage ¶
func (e *InvalidRequestException) ErrorMessage() string
type PreconditionFailedException ¶
type PreconditionFailedException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
func (*PreconditionFailedException) Error ¶
func (e *PreconditionFailedException) Error() string
func (*PreconditionFailedException) ErrorCode ¶
func (e *PreconditionFailedException) ErrorCode() string
func (*PreconditionFailedException) ErrorFault ¶
func (e *PreconditionFailedException) ErrorFault() smithy.ErrorFault
func (*PreconditionFailedException) ErrorMessage ¶
func (e *PreconditionFailedException) ErrorMessage() string
type RangeNotSatisfiableException ¶
type RangeNotSatisfiableException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
func (*RangeNotSatisfiableException) Error ¶
func (e *RangeNotSatisfiableException) Error() string
func (*RangeNotSatisfiableException) ErrorCode ¶
func (e *RangeNotSatisfiableException) ErrorCode() string
func (*RangeNotSatisfiableException) ErrorFault ¶
func (e *RangeNotSatisfiableException) ErrorFault() smithy.ErrorFault
func (*RangeNotSatisfiableException) ErrorMessage ¶
func (e *RangeNotSatisfiableException) ErrorMessage() string
type ResourceConflictException ¶
type ResourceConflictException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
func (*ResourceConflictException) Error ¶
func (e *ResourceConflictException) Error() string
func (*ResourceConflictException) ErrorCode ¶
func (e *ResourceConflictException) ErrorCode() string
func (*ResourceConflictException) ErrorFault ¶
func (e *ResourceConflictException) ErrorFault() smithy.ErrorFault
func (*ResourceConflictException) ErrorMessage ¶
func (e *ResourceConflictException) ErrorMessage() string
type ResourceNotFoundException ¶
type ResourceNotFoundException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
func (*ResourceNotFoundException) Error ¶
func (e *ResourceNotFoundException) Error() string
func (*ResourceNotFoundException) ErrorCode ¶
func (e *ResourceNotFoundException) ErrorCode() string
func (*ResourceNotFoundException) ErrorFault ¶
func (e *ResourceNotFoundException) ErrorFault() smithy.ErrorFault
func (*ResourceNotFoundException) ErrorMessage ¶
func (e *ResourceNotFoundException) ErrorMessage() string
Source Files ¶
- Version
- v1.24.0 (latest)
- Published
- Jan 7, 2025
- Platform
- linux/amd64
- Imports
- 3 packages
- Last checked
- 7 hours ago –
Tools for package owners.