package types
import "github.com/aws/aws-sdk-go-v2/service/iot1clickprojects/types"
Index ¶
- type DeviceTemplate
- type InternalFailureException
- func (e *InternalFailureException) Error() string
- func (e *InternalFailureException) ErrorCode() string
- func (e *InternalFailureException) ErrorFault() smithy.ErrorFault
- func (e *InternalFailureException) ErrorMessage() string
- type InvalidRequestException
- func (e *InvalidRequestException) Error() string
- func (e *InvalidRequestException) ErrorCode() string
- func (e *InvalidRequestException) ErrorFault() smithy.ErrorFault
- func (e *InvalidRequestException) ErrorMessage() string
- type PlacementDescription
- type PlacementSummary
- type PlacementTemplate
- type ProjectDescription
- type ProjectSummary
- type ResourceConflictException
- func (e *ResourceConflictException) Error() string
- func (e *ResourceConflictException) ErrorCode() string
- func (e *ResourceConflictException) ErrorFault() smithy.ErrorFault
- func (e *ResourceConflictException) ErrorMessage() string
- type ResourceNotFoundException
- func (e *ResourceNotFoundException) Error() string
- func (e *ResourceNotFoundException) ErrorCode() string
- func (e *ResourceNotFoundException) ErrorFault() smithy.ErrorFault
- func (e *ResourceNotFoundException) ErrorMessage() string
- type TooManyRequestsException
Types ¶
type DeviceTemplate ¶
type DeviceTemplate struct {
// An optional Lambda function to invoke instead of the default Lambda function
// provided by the placement template.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
CallbackOverrides map[string]string
// The device type, which currently must be "button" .
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
DeviceType *string
// contains filtered or unexported fields
}
An object representing a device for a placement template (see PlacementTemplate).
type InternalFailureException ¶
type InternalFailureException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
func (*InternalFailureException) Error ¶
func (e *InternalFailureException) Error() string
func (*InternalFailureException) ErrorCode ¶
func (e *InternalFailureException) ErrorCode() string
func (*InternalFailureException) ErrorFault ¶
func (e *InternalFailureException) ErrorFault() smithy.ErrorFault
func (*InternalFailureException) ErrorMessage ¶
func (e *InternalFailureException) ErrorMessage() string
type InvalidRequestException ¶
type InvalidRequestException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
func (*InvalidRequestException) Error ¶
func (e *InvalidRequestException) Error() string
func (*InvalidRequestException) ErrorCode ¶
func (e *InvalidRequestException) ErrorCode() string
func (*InvalidRequestException) ErrorFault ¶
func (e *InvalidRequestException) ErrorFault() smithy.ErrorFault
func (*InvalidRequestException) ErrorMessage ¶
func (e *InvalidRequestException) ErrorMessage() string
type PlacementDescription ¶
type PlacementDescription struct {
// The user-defined attributes associated with the placement.
//
// This member is required.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
Attributes map[string]string
// The date when the placement was initially created, in UNIX epoch time format.
//
// This member is required.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
CreatedDate *time.Time
// The name of the placement.
//
// This member is required.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
PlacementName *string
// The name of the project containing the placement.
//
// This member is required.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
ProjectName *string
// The date when the placement was last updated, in UNIX epoch time format. If the
// placement was not updated, then createdDate and updatedDate are the same.
//
// This member is required.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
UpdatedDate *time.Time
// contains filtered or unexported fields
}
An object describing a project's placement.
type PlacementSummary ¶
type PlacementSummary struct {
// The date when the placement was originally created, in UNIX epoch time format.
//
// This member is required.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
CreatedDate *time.Time
// The name of the placement being summarized.
//
// This member is required.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
PlacementName *string
// The name of the project containing the placement.
//
// This member is required.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
ProjectName *string
// The date when the placement was last updated, in UNIX epoch time format. If the
// placement was not updated, then createdDate and updatedDate are the same.
//
// This member is required.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
UpdatedDate *time.Time
// contains filtered or unexported fields
}
An object providing summary information for a particular placement.
type PlacementTemplate ¶
type PlacementTemplate struct {
// The default attributes (key/value pairs) to be applied to all placements using
// this template.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
DefaultAttributes map[string]string
// An object specifying the DeviceTemplate for all placements using this (PlacementTemplate ) template.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
DeviceTemplates map[string]DeviceTemplate
// contains filtered or unexported fields
}
An object defining the template for a placement.
type ProjectDescription ¶
type ProjectDescription struct {
// The date when the project was originally created, in UNIX epoch time format.
//
// This member is required.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
CreatedDate *time.Time
// The name of the project for which to obtain information from.
//
// This member is required.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
ProjectName *string
// The date when the project was last updated, in UNIX epoch time format. If the
// project was not updated, then createdDate and updatedDate are the same.
//
// This member is required.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
UpdatedDate *time.Time
// The ARN of the project.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
Arn *string
// The description of the project.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
Description *string
// An object describing the project's placement specifications.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
PlacementTemplate *PlacementTemplate
// The tags (metadata key/value pairs) associated with the project.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
Tags map[string]string
// contains filtered or unexported fields
}
An object providing detailed information for a particular project associated with an AWS account and region.
type ProjectSummary ¶
type ProjectSummary struct {
// The date when the project was originally created, in UNIX epoch time format.
//
// This member is required.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
CreatedDate *time.Time
// The name of the project being summarized.
//
// This member is required.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
ProjectName *string
// The date when the project was last updated, in UNIX epoch time format. If the
// project was not updated, then createdDate and updatedDate are the same.
//
// This member is required.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
UpdatedDate *time.Time
// The ARN of the project.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
Arn *string
// The tags (metadata key/value pairs) associated with the project.
//
// Deprecated: AWS has deprecated this service. It is no longer available for use.
Tags map[string]string
// contains filtered or unexported fields
}
An object providing summary information for a particular project for an associated AWS account and region.
type ResourceConflictException ¶
type ResourceConflictException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
func (*ResourceConflictException) Error ¶
func (e *ResourceConflictException) Error() string
func (*ResourceConflictException) ErrorCode ¶
func (e *ResourceConflictException) ErrorCode() string
func (*ResourceConflictException) ErrorFault ¶
func (e *ResourceConflictException) ErrorFault() smithy.ErrorFault
func (*ResourceConflictException) ErrorMessage ¶
func (e *ResourceConflictException) ErrorMessage() string
type ResourceNotFoundException ¶
type ResourceNotFoundException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
func (*ResourceNotFoundException) Error ¶
func (e *ResourceNotFoundException) Error() string
func (*ResourceNotFoundException) ErrorCode ¶
func (e *ResourceNotFoundException) ErrorCode() string
func (*ResourceNotFoundException) ErrorFault ¶
func (e *ResourceNotFoundException) ErrorFault() smithy.ErrorFault
func (*ResourceNotFoundException) ErrorMessage ¶
func (e *ResourceNotFoundException) ErrorMessage() string
type TooManyRequestsException ¶
type TooManyRequestsException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
func (*TooManyRequestsException) Error ¶
func (e *TooManyRequestsException) Error() string
func (*TooManyRequestsException) ErrorCode ¶
func (e *TooManyRequestsException) ErrorCode() string
func (*TooManyRequestsException) ErrorFault ¶
func (e *TooManyRequestsException) ErrorFault() smithy.ErrorFault
func (*TooManyRequestsException) ErrorMessage ¶
func (e *TooManyRequestsException) ErrorMessage() string
Source Files ¶
- Version
- v1.24.0 (latest)
- Published
- Jan 7, 2025
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 1 hour ago –
Tools for package owners.