Documentation
¶
Overview ¶
Package agentregistrycontrol provides the API client, operations, and parameter types for Agent Registry Control.
AWS Agent Registry is a managed catalog for publishing and discovering resources such as MCP servers, agents, and agent skills. Agent Registry Control is its control-plane API: use it to create and manage registries and the records they contain, configure discovery and authorization, govern record approval and curation workflows, and manage automatic detection of resources. Data-plane search and MCP invocation operations are provided by the companion Agent Registry API.
Index ¶
- Constants
- Variables
- func NewDefaultEndpointResolver() *internalendpoints.Resolver
- func WithAPIOptions(optFns ...func(*middleware.Stack) error) func(*Options)
- func WithEndpointResolver(v EndpointResolver) func(*Options)deprecated
- func WithEndpointResolverV2(v EndpointResolverV2) func(*Options)
- func WithSigV4SigningName(name string) func(*Options)
- func WithSigV4SigningRegion(region string) func(*Options)
- type AuthResolverParameters
- type AuthSchemeResolver
- type Client
- func (c *Client) CreateRegistry(ctx context.Context, params *CreateRegistryInput, optFns ...func(*Options)) (*CreateRegistryOutput, error)
- func (c *Client) CreateRegistryRecord(ctx context.Context, params *CreateRegistryRecordInput, ...) (*CreateRegistryRecordOutput, error)
- func (c *Client) DeleteRegistry(ctx context.Context, params *DeleteRegistryInput, optFns ...func(*Options)) (*DeleteRegistryOutput, error)
- func (c *Client) DeleteRegistryRecord(ctx context.Context, params *DeleteRegistryRecordInput, ...) (*DeleteRegistryRecordOutput, error)
- func (c *Client) GetRegistry(ctx context.Context, params *GetRegistryInput, optFns ...func(*Options)) (*GetRegistryOutput, error)
- func (c *Client) GetRegistryRecord(ctx context.Context, params *GetRegistryRecordInput, optFns ...func(*Options)) (*GetRegistryRecordOutput, error)
- func (c *Client) ListRegistries(ctx context.Context, params *ListRegistriesInput, optFns ...func(*Options)) (*ListRegistriesOutput, error)
- func (c *Client) ListRegistryRecords(ctx context.Context, params *ListRegistryRecordsInput, ...) (*ListRegistryRecordsOutput, error)
- func (c *Client) ListTagsForResource(ctx context.Context, params *ListTagsForResourceInput, ...) (*ListTagsForResourceOutput, error)
- func (c *Client) Options() Options
- func (c *Client) SubmitRegistryRecordForApproval(ctx context.Context, params *SubmitRegistryRecordForApprovalInput, ...) (*SubmitRegistryRecordForApprovalOutput, error)
- func (c *Client) TagResource(ctx context.Context, params *TagResourceInput, optFns ...func(*Options)) (*TagResourceOutput, error)
- func (c *Client) UntagResource(ctx context.Context, params *UntagResourceInput, optFns ...func(*Options)) (*UntagResourceOutput, error)
- func (c *Client) UpdateRegistry(ctx context.Context, params *UpdateRegistryInput, optFns ...func(*Options)) (*UpdateRegistryOutput, error)
- func (c *Client) UpdateRegistryRecord(ctx context.Context, params *UpdateRegistryRecordInput, ...) (*UpdateRegistryRecordOutput, error)
- func (c *Client) UpdateRegistryRecordStatus(ctx context.Context, params *UpdateRegistryRecordStatusInput, ...) (*UpdateRegistryRecordStatusOutput, error)
- type CreateRegistryInput
- type CreateRegistryOutput
- type CreateRegistryRecordInput
- type CreateRegistryRecordOutput
- type DeleteRegistryInput
- type DeleteRegistryOutput
- type DeleteRegistryRecordInput
- type DeleteRegistryRecordOutput
- type EndpointParameters
- type EndpointResolver
- type EndpointResolverFunc
- type EndpointResolverOptions
- type EndpointResolverV2
- type GetRegistryAPIClient
- type GetRegistryInput
- type GetRegistryOutput
- type GetRegistryRecordAPIClient
- type GetRegistryRecordInput
- type GetRegistryRecordOutput
- type HTTPClient
- type HTTPSignerV4
- type IdempotencyTokenProvider
- type ListRegistriesAPIClient
- type ListRegistriesInput
- type ListRegistriesOutput
- type ListRegistriesPaginator
- type ListRegistriesPaginatorOptions
- type ListRegistryRecordsAPIClient
- type ListRegistryRecordsInput
- type ListRegistryRecordsOutput
- type ListRegistryRecordsPaginator
- type ListRegistryRecordsPaginatorOptions
- type ListTagsForResourceInput
- type ListTagsForResourceOutput
- type Options
- type RegistryReadyWaiter
- type RegistryReadyWaiterOptions
- type RegistryRecordApprovedWaiter
- func (w *RegistryRecordApprovedWaiter) Wait(ctx context.Context, params *GetRegistryRecordInput, maxWaitDur time.Duration, ...) error
- func (w *RegistryRecordApprovedWaiter) WaitForOutput(ctx context.Context, params *GetRegistryRecordInput, maxWaitDur time.Duration, ...) (*GetRegistryRecordOutput, error)
- type RegistryRecordApprovedWaiterOptions
- type ResolveEndpoint
- type SubmitRegistryRecordForApprovalInput
- type SubmitRegistryRecordForApprovalOutput
- type TagResourceInput
- type TagResourceOutput
- type UntagResourceInput
- type UntagResourceOutput
- type UpdateRegistryInput
- type UpdateRegistryOutput
- type UpdateRegistryRecordInput
- type UpdateRegistryRecordOutput
- type UpdateRegistryRecordStatusInput
- type UpdateRegistryRecordStatusOutput
Constants ¶
const ServiceAPIVersion = "2025-12-01"
const ServiceID = "Agent Registry Control"
Variables ¶
var TypeRegistry = &smithy.TypeRegistry{ Entries: map[string]*smithy.TypeRegistryEntry{ "com.amazonaws.agentregistrycontrol#AccessDeniedException": { Schema: schemas.AccessDeniedException, New: func() any { return &types.AccessDeniedException{} }, }, "com.amazonaws.agentregistrycontrol#ConflictException": { Schema: schemas.ConflictException, New: func() any { return &types.ConflictException{} }, }, "com.amazonaws.agentregistrycontrol#InternalServerException": { Schema: schemas.InternalServerException, New: func() any { return &types.InternalServerException{} }, }, "com.amazonaws.agentregistrycontrol#ResourceNotFoundException": { Schema: schemas.ResourceNotFoundException, New: func() any { return &types.ResourceNotFoundException{} }, }, "com.amazonaws.agentregistrycontrol#ServiceQuotaExceededException": { Schema: schemas.ServiceQuotaExceededException, New: func() any { return &types.ServiceQuotaExceededException{} }, }, "com.amazonaws.agentregistrycontrol#ThrottlingException": { Schema: schemas.ThrottlingException, New: func() any { return &types.ThrottlingException{} }, }, "com.amazonaws.agentregistrycontrol#ValidationException": { Schema: schemas.ValidationException, New: func() any { return &types.ValidationException{} }, }, }, }
TypeRegistry is the type registry for this service.
Functions ¶
func NewDefaultEndpointResolver ¶
func NewDefaultEndpointResolver() *internalendpoints.Resolver
NewDefaultEndpointResolver constructs a new service endpoint resolver
func WithAPIOptions ¶
func WithAPIOptions(optFns ...func(*middleware.Stack) error) func(*Options)
WithAPIOptions returns a functional option for setting the Client's APIOptions option.
func WithEndpointResolver
deprecated
func WithEndpointResolver(v EndpointResolver) func(*Options)
Deprecated: EndpointResolver and WithEndpointResolver. Providing a value for this field will likely prevent you from using any endpoint-related service features released after the introduction of EndpointResolverV2 and BaseEndpoint.
To migrate an EndpointResolver implementation that uses a custom endpoint, set the client option BaseEndpoint instead.
func WithEndpointResolverV2 ¶
func WithEndpointResolverV2(v EndpointResolverV2) func(*Options)
WithEndpointResolverV2 returns a functional option for setting the Client's EndpointResolverV2 option.
func WithSigV4SigningName ¶
WithSigV4SigningName applies an override to the authentication workflow to use the given signing name for SigV4-authenticated operations.
This is an advanced setting. The value here is FINAL, taking precedence over the resolved signing name from both auth scheme resolution and endpoint resolution.
func WithSigV4SigningRegion ¶
WithSigV4SigningRegion applies an override to the authentication workflow to use the given signing region for SigV4-authenticated operations.
This is an advanced setting. The value here is FINAL, taking precedence over the resolved signing region from both auth scheme resolution and endpoint resolution.
Types ¶
type AuthResolverParameters ¶
type AuthResolverParameters struct {
// The name of the operation being invoked.
Operation string
// The region in which the operation is being invoked.
Region string
}
AuthResolverParameters contains the set of inputs necessary for auth scheme resolution.
type AuthSchemeResolver ¶
type AuthSchemeResolver interface {
ResolveAuthSchemes(context.Context, *AuthResolverParameters) ([]*smithyauth.Option, error)
}
AuthSchemeResolver returns a set of possible authentication options for an operation.
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client provides the API client to make operations call for Agent Registry Control.
func New ¶
New returns an initialized Client based on the functional options. Provide additional functional options to further configure the behavior of the client, such as changing the client's endpoint or adding custom middleware behavior.
func NewFromConfig ¶
NewFromConfig returns a new client from the provided config.
func (*Client) CreateRegistry ¶
func (c *Client) CreateRegistry(ctx context.Context, params *CreateRegistryInput, optFns ...func(*Options)) (*CreateRegistryOutput, error)
Creates a new registry, a catalog that organizes registry records and defines their discovery authorization and record approval behavior. Creation is asynchronous: the registry begins in the CREATING status and becomes usable once it reaches READY.
func (*Client) CreateRegistryRecord ¶
func (c *Client) CreateRegistryRecord(ctx context.Context, params *CreateRegistryRecordInput, optFns ...func(*Options)) (*CreateRegistryRecordOutput, error)
Creates a registry record within a registry. A registry record describes a discoverable resource, such as an MCP server, an agent, an agent skill, or a custom resource. Creation is asynchronous: the record is returned with the CREATING status while it is processed.
func (*Client) DeleteRegistry ¶
func (c *Client) DeleteRegistry(ctx context.Context, params *DeleteRegistryInput, optFns ...func(*Options)) (*DeleteRegistryOutput, error)
Deletes a registry. Deletion is asynchronous: the registry transitions to the DELETING status and is removed along with its registry records.
func (*Client) DeleteRegistryRecord ¶
func (c *Client) DeleteRegistryRecord(ctx context.Context, params *DeleteRegistryRecordInput, optFns ...func(*Options)) (*DeleteRegistryRecordOutput, error)
Deletes a registry record
func (*Client) GetRegistry ¶
func (c *Client) GetRegistry(ctx context.Context, params *GetRegistryInput, optFns ...func(*Options)) (*GetRegistryOutput, error)
Gets a registry by identifier (ARN or ID)
func (*Client) GetRegistryRecord ¶
func (c *Client) GetRegistryRecord(ctx context.Context, params *GetRegistryRecordInput, optFns ...func(*Options)) (*GetRegistryRecordOutput, error)
Retrieves the details of a registry record
func (*Client) ListRegistries ¶
func (c *Client) ListRegistries(ctx context.Context, params *ListRegistriesInput, optFns ...func(*Options)) (*ListRegistriesOutput, error)
Lists the registries in the caller's account and Region, with optional filtering by status and discovery authorizer type
func (*Client) ListRegistryRecords ¶
func (c *Client) ListRegistryRecords(ctx context.Context, params *ListRegistryRecordsInput, optFns ...func(*Options)) (*ListRegistryRecordsOutput, error)
Lists the registry records within a registry, with optional filtering by name, status, and record type
func (*Client) ListTagsForResource ¶
func (c *Client) ListTagsForResource(ctx context.Context, params *ListTagsForResourceInput, optFns ...func(*Options)) (*ListTagsForResourceOutput, error)
List the tags on a resource
func (*Client) Options ¶
Options returns a copy of the client configuration.
Callers SHOULD NOT perform mutations on any inner structures within client config. Config overrides should instead be made on a per-operation basis through functional options.
func (*Client) SubmitRegistryRecordForApproval ¶
func (c *Client) SubmitRegistryRecordForApproval(ctx context.Context, params *SubmitRegistryRecordForApprovalInput, optFns ...func(*Options)) (*SubmitRegistryRecordForApprovalOutput, error)
Submits a DRAFT registry record for approval, moving it into the registry's approval workflow. Depending on the registry's approval configuration, the record is either auto-approved or set to PENDING_APPROVAL for a curator to approve or reject.
func (*Client) TagResource ¶
func (c *Client) TagResource(ctx context.Context, params *TagResourceInput, optFns ...func(*Options)) (*TagResourceOutput, error)
Tag a resource with key-value pairs
func (*Client) UntagResource ¶
func (c *Client) UntagResource(ctx context.Context, params *UntagResourceInput, optFns ...func(*Options)) (*UntagResourceOutput, error)
Remove tags from a resource by key
func (*Client) UpdateRegistry ¶
func (c *Client) UpdateRegistry(ctx context.Context, params *UpdateRegistryInput, optFns ...func(*Options)) (*UpdateRegistryOutput, error)
Updates an existing registry. This operation uses PATCH semantics: specify only the fields you want to change, and omit the rest to leave them unchanged. Updates are applied asynchronously and the registry transitions to the UPDATING status while they are processed.
func (*Client) UpdateRegistryRecord ¶
func (c *Client) UpdateRegistryRecord(ctx context.Context, params *UpdateRegistryRecordInput, optFns ...func(*Options)) (*UpdateRegistryRecordOutput, error)
Updates a registry record. The update is asynchronous: the record is returned with the UPDATING status while it is processed. Fields that use update wrappers follow PATCH semantics: omit the field to leave it unchanged.
func (*Client) UpdateRegistryRecordStatus ¶
func (c *Client) UpdateRegistryRecordStatus(ctx context.Context, params *UpdateRegistryRecordStatusInput, optFns ...func(*Options)) (*UpdateRegistryRecordStatusOutput, error)
Updates the status of a registry record as part of the registry's curation workflow, for example to approve or reject a record that is pending approval, or to deprecate an approved record so that it is no longer discoverable
type CreateRegistryInput ¶
type CreateRegistryInput struct {
// The name of the registry
//
// This member is required.
Name *string
// Approval configuration for registry records
ApprovalConfiguration *types.ApprovalConfiguration
// Client token for idempotency
ClientToken *string
// The description of the registry
Description *string
// Discovery configuration for the registry
DiscoveryConfiguration *types.DiscoveryConfiguration
// Tags to associate with the registry
Tags map[string]string
// contains filtered or unexported fields
}
Request structure for creating a registry
func (*CreateRegistryInput) Serialize ¶
func (v *CreateRegistryInput) Serialize(s smithy.ShapeSerializer)
func (*CreateRegistryInput) SerializeMembers ¶
func (v *CreateRegistryInput) SerializeMembers(s smithy.ShapeSerializer)
type CreateRegistryOutput ¶
type CreateRegistryOutput struct {
// The ARN of the created registry
//
// This member is required.
RegistryArn *string
// Metadata pertaining to the operation's result.
ResultMetadata middleware.Metadata
// contains filtered or unexported fields
}
Response structure for creating a registry
func (*CreateRegistryOutput) Deserialize ¶
func (v *CreateRegistryOutput) Deserialize(d smithy.ShapeDeserializer) error
func (*CreateRegistryOutput) Serialize ¶
func (v *CreateRegistryOutput) Serialize(s smithy.ShapeSerializer)
func (*CreateRegistryOutput) SerializeMembers ¶
func (v *CreateRegistryOutput) SerializeMembers(s smithy.ShapeSerializer)
type CreateRegistryRecordInput ¶
type CreateRegistryRecordInput struct {
// The typed descriptor content for the registry record
//
// This member is required.
Descriptors *types.Descriptors
// The name of the registry record
//
// This member is required.
Name *string
// The type of the registry record, which determines the descriptor format
//
// This member is required.
RecordType types.RecordType
// The identifier of the registry in which to create the record (ARN or ID)
//
// This member is required.
RegistryId *string
// Client token for idempotency
ClientToken *string
// The description of the registry record
Description *string
// The human-readable display name of the registry record
DisplayName *string
// The version of the registry record
RecordVersion *string
// Tags to associate with the registry record
Tags map[string]string
// contains filtered or unexported fields
}
func (*CreateRegistryRecordInput) Serialize ¶
func (v *CreateRegistryRecordInput) Serialize(s smithy.ShapeSerializer)
func (*CreateRegistryRecordInput) SerializeMembers ¶
func (v *CreateRegistryRecordInput) SerializeMembers(s smithy.ShapeSerializer)
type CreateRegistryRecordOutput ¶
type CreateRegistryRecordOutput struct {
// The ARN of the created registry record
//
// This member is required.
RecordArn *string
// The status of the registry record, set to CREATING while the asynchronous
// workflow is in progress
//
// This member is required.
Status types.RegistryRecordStatus
// Metadata pertaining to the operation's result.
ResultMetadata middleware.Metadata
// contains filtered or unexported fields
}
Response structure for creating a registry record
func (*CreateRegistryRecordOutput) Deserialize ¶
func (v *CreateRegistryRecordOutput) Deserialize(d smithy.ShapeDeserializer) error
func (*CreateRegistryRecordOutput) Serialize ¶
func (v *CreateRegistryRecordOutput) Serialize(s smithy.ShapeSerializer)
func (*CreateRegistryRecordOutput) SerializeMembers ¶
func (v *CreateRegistryRecordOutput) SerializeMembers(s smithy.ShapeSerializer)
type DeleteRegistryInput ¶
type DeleteRegistryInput struct {
// The identifier of the registry to delete (ARN or ID)
//
// This member is required.
RegistryId *string
// contains filtered or unexported fields
}
Request structure for deleting a registry
func (*DeleteRegistryInput) Serialize ¶
func (v *DeleteRegistryInput) Serialize(s smithy.ShapeSerializer)
func (*DeleteRegistryInput) SerializeMembers ¶
func (v *DeleteRegistryInput) SerializeMembers(s smithy.ShapeSerializer)
type DeleteRegistryOutput ¶
type DeleteRegistryOutput struct {
// Current status of the registry, set to DELETING when deletion is initiated
//
// This member is required.
Status types.RegistryStatus
// Metadata pertaining to the operation's result.
ResultMetadata middleware.Metadata
// contains filtered or unexported fields
}
Response structure for deleting a registry
func (*DeleteRegistryOutput) Deserialize ¶
func (v *DeleteRegistryOutput) Deserialize(d smithy.ShapeDeserializer) error
func (*DeleteRegistryOutput) Serialize ¶
func (v *DeleteRegistryOutput) Serialize(s smithy.ShapeSerializer)
func (*DeleteRegistryOutput) SerializeMembers ¶
func (v *DeleteRegistryOutput) SerializeMembers(s smithy.ShapeSerializer)
type DeleteRegistryRecordInput ¶
type DeleteRegistryRecordInput struct {
// The identifier of the registry record to delete (ARN or ID)
//
// This member is required.
RecordId *string
// The identifier of the registry containing the record (ARN or ID)
//
// This member is required.
RegistryId *string
// contains filtered or unexported fields
}
func (*DeleteRegistryRecordInput) Serialize ¶
func (v *DeleteRegistryRecordInput) Serialize(s smithy.ShapeSerializer)
func (*DeleteRegistryRecordInput) SerializeMembers ¶
func (v *DeleteRegistryRecordInput) SerializeMembers(s smithy.ShapeSerializer)
type DeleteRegistryRecordOutput ¶
type DeleteRegistryRecordOutput struct {
// Metadata pertaining to the operation's result.
ResultMetadata middleware.Metadata
// contains filtered or unexported fields
}
Response structure for deleting a registry record
func (*DeleteRegistryRecordOutput) Deserialize ¶
func (v *DeleteRegistryRecordOutput) Deserialize(d smithy.ShapeDeserializer) error
func (*DeleteRegistryRecordOutput) Serialize ¶
func (v *DeleteRegistryRecordOutput) Serialize(s smithy.ShapeSerializer)
func (*DeleteRegistryRecordOutput) SerializeMembers ¶
func (v *DeleteRegistryRecordOutput) SerializeMembers(s smithy.ShapeSerializer)
type EndpointParameters ¶
type EndpointParameters struct {
// The AWS region of the service.
//
// Parameter is required.
//
// AWS::Region
Region *string
// Override the endpoint used to send requests.
//
// Parameter is
// required.
//
// SDK::Endpoint
Endpoint *string
}
EndpointParameters provides the parameters that influence how endpoints are resolved.
func (EndpointParameters) WithDefaults ¶
func (p EndpointParameters) WithDefaults() EndpointParameters
WithDefaults returns a shallow copy of EndpointParameterswith default values applied to members where applicable.
type EndpointResolver ¶
type EndpointResolver interface {
ResolveEndpoint(region string, options EndpointResolverOptions) (aws.Endpoint, error)
}
EndpointResolver interface for resolving service endpoints.
func EndpointResolverFromURL ¶
func EndpointResolverFromURL(url string, optFns ...func(*aws.Endpoint)) EndpointResolver
EndpointResolverFromURL returns an EndpointResolver configured using the provided endpoint url. By default, the resolved endpoint resolver uses the client region as signing region, and the endpoint source is set to EndpointSourceCustom.You can provide functional options to configure endpoint values for the resolved endpoint.
type EndpointResolverFunc ¶
type EndpointResolverFunc func(region string, options EndpointResolverOptions) (aws.Endpoint, error)
EndpointResolverFunc is a helper utility that wraps a function so it satisfies the EndpointResolver interface. This is useful when you want to add additional endpoint resolving logic, or stub out specific endpoints with custom values.
func (EndpointResolverFunc) ResolveEndpoint ¶
func (fn EndpointResolverFunc) ResolveEndpoint(region string, options EndpointResolverOptions) (endpoint aws.Endpoint, err error)
type EndpointResolverOptions ¶
type EndpointResolverOptions = internalendpoints.Options
EndpointResolverOptions is the service endpoint resolver options
type EndpointResolverV2 ¶
type EndpointResolverV2 interface {
ResolveEndpoint(ctx context.Context, params EndpointParameters) (
smithyendpoints.Endpoint, error,
)
}
EndpointResolverV2 provides the interface for resolving service endpoints.
func NewDefaultEndpointResolverV2 ¶
func NewDefaultEndpointResolverV2() EndpointResolverV2
type GetRegistryAPIClient ¶
type GetRegistryAPIClient interface {
GetRegistry(context.Context, *GetRegistryInput, ...func(*Options)) (*GetRegistryOutput, error)
}
GetRegistryAPIClient is a client that implements the GetRegistry operation.
type GetRegistryInput ¶
type GetRegistryInput struct {
// The identifier of the registry to retrieve (ARN or ID)
//
// This member is required.
RegistryId *string
// contains filtered or unexported fields
}
Request structure for getting a registry
func (*GetRegistryInput) Serialize ¶
func (v *GetRegistryInput) Serialize(s smithy.ShapeSerializer)
func (*GetRegistryInput) SerializeMembers ¶
func (v *GetRegistryInput) SerializeMembers(s smithy.ShapeSerializer)
type GetRegistryOutput ¶
type GetRegistryOutput struct {
// The timestamp when the registry was created
//
// This member is required.
CreatedAt *time.Time
// The name of the registry
//
// This member is required.
Name *string
// The ARN of the registry
//
// This member is required.
RegistryArn *string
// The unique identifier of the registry
//
// This member is required.
RegistryId *string
// Current status of the registry
//
// This member is required.
Status types.RegistryStatus
// The timestamp when the registry was last updated
//
// This member is required.
UpdatedAt *time.Time
// Approval configuration for registry records
ApprovalConfiguration *types.ApprovalConfiguration
// The description of the registry
Description *string
// Discovery configuration for the registry
DiscoveryConfiguration *types.DiscoveryConfiguration
// The reason for the current status. Typically populated when the status
// indicates a failure state.
StatusReason *string
// Metadata pertaining to the operation's result.
ResultMetadata middleware.Metadata
// contains filtered or unexported fields
}
Response structure for getting a registry
func (*GetRegistryOutput) Deserialize ¶
func (v *GetRegistryOutput) Deserialize(d smithy.ShapeDeserializer) error
func (*GetRegistryOutput) Serialize ¶
func (v *GetRegistryOutput) Serialize(s smithy.ShapeSerializer)
func (*GetRegistryOutput) SerializeMembers ¶
func (v *GetRegistryOutput) SerializeMembers(s smithy.ShapeSerializer)
type GetRegistryRecordAPIClient ¶
type GetRegistryRecordAPIClient interface {
GetRegistryRecord(context.Context, *GetRegistryRecordInput, ...func(*Options)) (*GetRegistryRecordOutput, error)
}
GetRegistryRecordAPIClient is a client that implements the GetRegistryRecord operation.
type GetRegistryRecordInput ¶
type GetRegistryRecordInput struct {
// The identifier of the registry record to retrieve (ARN or ID)
//
// This member is required.
RecordId *string
// The identifier of the registry containing the record (ARN or ID)
//
// This member is required.
RegistryId *string
// contains filtered or unexported fields
}
func (*GetRegistryRecordInput) Serialize ¶
func (v *GetRegistryRecordInput) Serialize(s smithy.ShapeSerializer)
func (*GetRegistryRecordInput) SerializeMembers ¶
func (v *GetRegistryRecordInput) SerializeMembers(s smithy.ShapeSerializer)
type GetRegistryRecordOutput ¶
type GetRegistryRecordOutput struct {
// The timestamp when the registry record was created.
//
// This member is required.
CreatedAt *time.Time
// The name of the registry record. Names are unique within a registry.
//
// This member is required.
Name *string
// The &ARN; of the registry record.
//
// This member is required.
RecordArn *string
// The unique identifier of the registry record.
//
// This member is required.
RecordId *string
// The type of the registry record, such as MCP, AGENT, SKILL, or CUSTOM.
//
// This member is required.
RecordType types.RecordType
// The &ARN; of the parent registry that owns the record.
//
// This member is required.
RegistryArn *string
// The lifecycle status of the registry record.
//
// This member is required.
Status types.RegistryRecordStatus
// The timestamp when the registry record was last updated.
//
// This member is required.
UpdatedAt *time.Time
// A description of the registry record.
Description *string
// The typed descriptors that define the content of the registry record.
Descriptors *types.Descriptors
// The human-readable display name of the registry record.
DisplayName *string
// The version identifier of the registry record.
RecordVersion *string
// The reason for the current status. Typically populated when the status
// indicates a failure state.
StatusReason *string
// Metadata pertaining to the operation's result.
ResultMetadata middleware.Metadata
// contains filtered or unexported fields
}
Response structure for retrieving a registry record
func (*GetRegistryRecordOutput) Deserialize ¶
func (v *GetRegistryRecordOutput) Deserialize(d smithy.ShapeDeserializer) error
func (*GetRegistryRecordOutput) Serialize ¶
func (v *GetRegistryRecordOutput) Serialize(s smithy.ShapeSerializer)
func (*GetRegistryRecordOutput) SerializeMembers ¶
func (v *GetRegistryRecordOutput) SerializeMembers(s smithy.ShapeSerializer)
type HTTPSignerV4 ¶
type IdempotencyTokenProvider ¶
IdempotencyTokenProvider interface for providing idempotency token
type ListRegistriesAPIClient ¶
type ListRegistriesAPIClient interface {
ListRegistries(context.Context, *ListRegistriesInput, ...func(*Options)) (*ListRegistriesOutput, error)
}
ListRegistriesAPIClient is a client that implements the ListRegistries operation.
type ListRegistriesInput ¶
type ListRegistriesInput struct {
// Filters to apply to the registry list
Filters []types.RegistryFilter
// Maximum number of results to return
MaxResults *int32
// Token for pagination
NextToken *string
// contains filtered or unexported fields
}
Request structure for listing registries
func (*ListRegistriesInput) Serialize ¶
func (v *ListRegistriesInput) Serialize(s smithy.ShapeSerializer)
func (*ListRegistriesInput) SerializeMembers ¶
func (v *ListRegistriesInput) SerializeMembers(s smithy.ShapeSerializer)
type ListRegistriesOutput ¶
type ListRegistriesOutput struct {
// List of registry summaries
//
// This member is required.
Registries []types.RegistrySummary
// Token for next page of results
NextToken *string
// Metadata pertaining to the operation's result.
ResultMetadata middleware.Metadata
// contains filtered or unexported fields
}
Response structure for listing registries
func (*ListRegistriesOutput) Deserialize ¶
func (v *ListRegistriesOutput) Deserialize(d smithy.ShapeDeserializer) error
func (*ListRegistriesOutput) Serialize ¶
func (v *ListRegistriesOutput) Serialize(s smithy.ShapeSerializer)
func (*ListRegistriesOutput) SerializeMembers ¶
func (v *ListRegistriesOutput) SerializeMembers(s smithy.ShapeSerializer)
type ListRegistriesPaginator ¶
type ListRegistriesPaginator struct {
// contains filtered or unexported fields
}
ListRegistriesPaginator is a paginator for ListRegistries
func NewListRegistriesPaginator ¶
func NewListRegistriesPaginator(client ListRegistriesAPIClient, params *ListRegistriesInput, optFns ...func(*ListRegistriesPaginatorOptions)) *ListRegistriesPaginator
NewListRegistriesPaginator returns a new ListRegistriesPaginator
func (*ListRegistriesPaginator) HasMorePages ¶
func (p *ListRegistriesPaginator) HasMorePages() bool
HasMorePages returns a boolean indicating whether more pages are available
func (*ListRegistriesPaginator) NextPage ¶
func (p *ListRegistriesPaginator) NextPage(ctx context.Context, optFns ...func(*Options)) (*ListRegistriesOutput, error)
NextPage retrieves the next ListRegistries page.
type ListRegistriesPaginatorOptions ¶
type ListRegistriesPaginatorOptions struct {
// Maximum number of results to return
Limit int32
// Set to true if pagination should stop if the service returns a pagination token
// that matches the most recent token provided to the service.
StopOnDuplicateToken bool
}
ListRegistriesPaginatorOptions is the paginator options for ListRegistries
type ListRegistryRecordsAPIClient ¶
type ListRegistryRecordsAPIClient interface {
ListRegistryRecords(context.Context, *ListRegistryRecordsInput, ...func(*Options)) (*ListRegistryRecordsOutput, error)
}
ListRegistryRecordsAPIClient is a client that implements the ListRegistryRecords operation.
type ListRegistryRecordsInput ¶
type ListRegistryRecordsInput struct {
// The identifier of the registry to list records from (ARN or ID)
//
// This member is required.
RegistryId *string
// Filters to apply to the registry record list
Filters []types.RegistryRecordFilter
// Maximum number of records to return
MaxResults *int32
// Token for pagination
NextToken *string
// contains filtered or unexported fields
}
func (*ListRegistryRecordsInput) Serialize ¶
func (v *ListRegistryRecordsInput) Serialize(s smithy.ShapeSerializer)
func (*ListRegistryRecordsInput) SerializeMembers ¶
func (v *ListRegistryRecordsInput) SerializeMembers(s smithy.ShapeSerializer)
type ListRegistryRecordsOutput ¶
type ListRegistryRecordsOutput struct {
// List of registry record summaries
//
// This member is required.
RegistryRecords []types.RegistryRecordSummary
// Token for next page of results
NextToken *string
// Metadata pertaining to the operation's result.
ResultMetadata middleware.Metadata
// contains filtered or unexported fields
}
Response structure for listing registry records
func (*ListRegistryRecordsOutput) Deserialize ¶
func (v *ListRegistryRecordsOutput) Deserialize(d smithy.ShapeDeserializer) error
func (*ListRegistryRecordsOutput) Serialize ¶
func (v *ListRegistryRecordsOutput) Serialize(s smithy.ShapeSerializer)
func (*ListRegistryRecordsOutput) SerializeMembers ¶
func (v *ListRegistryRecordsOutput) SerializeMembers(s smithy.ShapeSerializer)
type ListRegistryRecordsPaginator ¶
type ListRegistryRecordsPaginator struct {
// contains filtered or unexported fields
}
ListRegistryRecordsPaginator is a paginator for ListRegistryRecords
func NewListRegistryRecordsPaginator ¶
func NewListRegistryRecordsPaginator(client ListRegistryRecordsAPIClient, params *ListRegistryRecordsInput, optFns ...func(*ListRegistryRecordsPaginatorOptions)) *ListRegistryRecordsPaginator
NewListRegistryRecordsPaginator returns a new ListRegistryRecordsPaginator
func (*ListRegistryRecordsPaginator) HasMorePages ¶
func (p *ListRegistryRecordsPaginator) HasMorePages() bool
HasMorePages returns a boolean indicating whether more pages are available
func (*ListRegistryRecordsPaginator) NextPage ¶
func (p *ListRegistryRecordsPaginator) NextPage(ctx context.Context, optFns ...func(*Options)) (*ListRegistryRecordsOutput, error)
NextPage retrieves the next ListRegistryRecords page.
type ListRegistryRecordsPaginatorOptions ¶
type ListRegistryRecordsPaginatorOptions struct {
// Maximum number of records to return
Limit int32
// Set to true if pagination should stop if the service returns a pagination token
// that matches the most recent token provided to the service.
StopOnDuplicateToken bool
}
ListRegistryRecordsPaginatorOptions is the paginator options for ListRegistryRecords
type ListTagsForResourceInput ¶
type ListTagsForResourceInput struct {
// ARN of a taggable Agent Registry resource.
//
// This member is required.
ResourceArn *string
// contains filtered or unexported fields
}
func (*ListTagsForResourceInput) Serialize ¶
func (v *ListTagsForResourceInput) Serialize(s smithy.ShapeSerializer)
func (*ListTagsForResourceInput) SerializeMembers ¶
func (v *ListTagsForResourceInput) SerializeMembers(s smithy.ShapeSerializer)
type ListTagsForResourceOutput ¶
type ListTagsForResourceOutput struct {
// A map of tag keys to tag values returned by read operations (may be empty).
Tags map[string]string
// Metadata pertaining to the operation's result.
ResultMetadata middleware.Metadata
// contains filtered or unexported fields
}
func (*ListTagsForResourceOutput) Deserialize ¶
func (v *ListTagsForResourceOutput) Deserialize(d smithy.ShapeDeserializer) error
func (*ListTagsForResourceOutput) Serialize ¶
func (v *ListTagsForResourceOutput) Serialize(s smithy.ShapeSerializer)
func (*ListTagsForResourceOutput) SerializeMembers ¶
func (v *ListTagsForResourceOutput) SerializeMembers(s smithy.ShapeSerializer)
type Options ¶
type Options struct {
// Set of options to modify how an operation is invoked. These apply to all
// operations invoked for this client. Use functional options on operation call to
// modify this list for per operation behavior.
APIOptions []func(*middleware.Stack) error
// The optional application specific identifier appended to the User-Agent header.
AppID string
// This endpoint will be given as input to an EndpointResolverV2. It is used for
// providing a custom base endpoint that is subject to modifications by the
// processing EndpointResolverV2.
BaseEndpoint *string
// Configures the events that will be sent to the configured logger.
ClientLogMode aws.ClientLogMode
// The credentials object to use when signing requests.
Credentials aws.CredentialsProvider
// The configuration DefaultsMode that the SDK should use when constructing the
// clients initial default settings.
DefaultsMode aws.DefaultsMode
// Disables SDK clock skew correction. When set, the SDK will not adjust request
// signing timestamps to compensate for clock drift between the client and the
// service.
DisableClockSkewCorrection bool
// The endpoint options to be used when attempting to resolve an endpoint.
EndpointOptions EndpointResolverOptions
// The service endpoint resolver.
//
// Deprecated: Deprecated: EndpointResolver and WithEndpointResolver. Providing a
// value for this field will likely prevent you from using any endpoint-related
// service features released after the introduction of EndpointResolverV2 and
// BaseEndpoint.
//
// To migrate an EndpointResolver implementation that uses a custom endpoint, set
// the client option BaseEndpoint instead.
EndpointResolver EndpointResolver
// Resolves the endpoint used for a particular service operation.
EndpointResolverV2 EndpointResolverV2
// Signature Version 4 (SigV4) Signer
HTTPSignerV4 HTTPSignerV4
// Provides idempotency tokens values that will be automatically populated into
// idempotent API operations.
IdempotencyTokenProvider IdempotencyTokenProvider
// The logger writer interface to write logging messages to.
Logger logging.Logger
// The client meter provider.
MeterProvider metrics.MeterProvider
// The region to send requests to. (Required)
Region string
// RetryMaxAttempts specifies the maximum number attempts an API client will call
// an operation that fails with a retryable error. A value of 0 is ignored, and
// will not be used to configure the API client created default retryer, or modify
// per operation call's retry max attempts.
//
// If specified in an operation call's functional options with a value that is
// different than the constructed client's Options, the Client's Retryer will be
// wrapped to use the operation's specific RetryMaxAttempts value.
RetryMaxAttempts int
// RetryMode specifies the retry mode the API client will be created with, if
// Retryer option is not also specified.
//
// When creating a new API Clients this member will only be used if the Retryer
// Options member is nil. This value will be ignored if Retryer is not nil.
//
// Currently does not support per operation call overrides, may in the future.
RetryMode aws.RetryMode
// Retryer guides how HTTP requests should be retried in case of recoverable
// failures. When nil the API client will use a default retryer. The kind of
// default retry created by the API client can be changed with the RetryMode
// option.
Retryer aws.Retryer
// The RuntimeEnvironment configuration, only populated if the DefaultsMode is set
// to DefaultsModeAuto and is initialized using config.LoadDefaultConfig . You
// should not populate this structure programmatically, or rely on the values here
// within your applications.
RuntimeEnvironment aws.RuntimeEnvironment
// The client tracer provider.
TracerProvider tracing.TracerProvider
Protocol smithyhttp.ClientProtocol
// The HTTP client to invoke API calls with. Defaults to client's default HTTP
// implementation if nil.
HTTPClient HTTPClient
// Client registry of operation interceptors.
Interceptors smithyhttp.InterceptorRegistry
// The auth scheme resolver which determines how to authenticate for each
// operation.
AuthSchemeResolver AuthSchemeResolver
// The list of auth schemes supported by the client.
AuthSchemes []smithyhttp.AuthScheme
// Priority list of preferred auth scheme names (e.g. sigv4a).
AuthSchemePreference []string
// contains filtered or unexported fields
}
func (Options) GetIdentityResolver ¶
func (o Options) GetIdentityResolver(schemeID string) smithyauth.IdentityResolver
type RegistryReadyWaiter ¶
type RegistryReadyWaiter struct {
// contains filtered or unexported fields
}
RegistryReadyWaiter defines the waiters for RegistryReady
func NewRegistryReadyWaiter ¶
func NewRegistryReadyWaiter(client GetRegistryAPIClient, optFns ...func(*RegistryReadyWaiterOptions)) *RegistryReadyWaiter
NewRegistryReadyWaiter constructs a RegistryReadyWaiter.
func (*RegistryReadyWaiter) Wait ¶
func (w *RegistryReadyWaiter) Wait(ctx context.Context, params *GetRegistryInput, maxWaitDur time.Duration, optFns ...func(*RegistryReadyWaiterOptions)) error
Wait calls the waiter function for RegistryReady waiter. The maxWaitDur is the maximum wait duration the waiter will wait. The maxWaitDur is required and must be greater than zero.
func (*RegistryReadyWaiter) WaitForOutput ¶
func (w *RegistryReadyWaiter) WaitForOutput(ctx context.Context, params *GetRegistryInput, maxWaitDur time.Duration, optFns ...func(*RegistryReadyWaiterOptions)) (*GetRegistryOutput, error)
WaitForOutput calls the waiter function for RegistryReady waiter and returns the output of the successful operation. The maxWaitDur is the maximum wait duration the waiter will wait. The maxWaitDur is required and must be greater than zero.
type RegistryReadyWaiterOptions ¶
type RegistryReadyWaiterOptions struct {
// Set of options to modify how an operation is invoked. These apply to all
// operations invoked for this client. Use functional options on operation call to
// modify this list for per operation behavior.
//
// Passing options here is functionally equivalent to passing values to this
// config's ClientOptions field that extend the inner client's APIOptions directly.
APIOptions []func(*middleware.Stack) error
// Functional options to be passed to all operations invoked by this client.
//
// Function values that modify the inner APIOptions are applied after the waiter
// config's own APIOptions modifiers.
ClientOptions []func(*Options)
// MinDelay is the minimum amount of time to delay between retries. If unset,
// RegistryReadyWaiter will use default minimum delay of 30 seconds. Note that
// MinDelay must resolve to a value lesser than or equal to the MaxDelay.
MinDelay time.Duration
// MaxDelay is the maximum amount of time to delay between retries. If unset or
// set to zero, RegistryReadyWaiter will use default max delay of 120 seconds. Note
// that MaxDelay must resolve to value greater than or equal to the MinDelay.
MaxDelay time.Duration
// LogWaitAttempts is used to enable logging for waiter retry attempts
LogWaitAttempts bool
// Retryable is function that can be used to override the service defined
// waiter-behavior based on operation output, or returned error. This function is
// used by the waiter to decide if a state is retryable or a terminal state.
//
// By default service-modeled logic will populate this option. This option can
// thus be used to define a custom waiter state with fall-back to service-modeled
// waiter state mutators.The function returns an error in case of a failure state.
// In case of retry state, this function returns a bool value of true and nil
// error, while in case of success it returns a bool value of false and nil error.
Retryable func(context.Context, *GetRegistryInput, *GetRegistryOutput, error) (bool, error)
}
RegistryReadyWaiterOptions are waiter options for RegistryReadyWaiter
type RegistryRecordApprovedWaiter ¶
type RegistryRecordApprovedWaiter struct {
// contains filtered or unexported fields
}
RegistryRecordApprovedWaiter defines the waiters for RegistryRecordApproved
func NewRegistryRecordApprovedWaiter ¶
func NewRegistryRecordApprovedWaiter(client GetRegistryRecordAPIClient, optFns ...func(*RegistryRecordApprovedWaiterOptions)) *RegistryRecordApprovedWaiter
NewRegistryRecordApprovedWaiter constructs a RegistryRecordApprovedWaiter.
func (*RegistryRecordApprovedWaiter) Wait ¶
func (w *RegistryRecordApprovedWaiter) Wait(ctx context.Context, params *GetRegistryRecordInput, maxWaitDur time.Duration, optFns ...func(*RegistryRecordApprovedWaiterOptions)) error
Wait calls the waiter function for RegistryRecordApproved waiter. The maxWaitDur is the maximum wait duration the waiter will wait. The maxWaitDur is required and must be greater than zero.
func (*RegistryRecordApprovedWaiter) WaitForOutput ¶
func (w *RegistryRecordApprovedWaiter) WaitForOutput(ctx context.Context, params *GetRegistryRecordInput, maxWaitDur time.Duration, optFns ...func(*RegistryRecordApprovedWaiterOptions)) (*GetRegistryRecordOutput, error)
WaitForOutput calls the waiter function for RegistryRecordApproved waiter and returns the output of the successful operation. The maxWaitDur is the maximum wait duration the waiter will wait. The maxWaitDur is required and must be greater than zero.
type RegistryRecordApprovedWaiterOptions ¶
type RegistryRecordApprovedWaiterOptions struct {
// Set of options to modify how an operation is invoked. These apply to all
// operations invoked for this client. Use functional options on operation call to
// modify this list for per operation behavior.
//
// Passing options here is functionally equivalent to passing values to this
// config's ClientOptions field that extend the inner client's APIOptions directly.
APIOptions []func(*middleware.Stack) error
// Functional options to be passed to all operations invoked by this client.
//
// Function values that modify the inner APIOptions are applied after the waiter
// config's own APIOptions modifiers.
ClientOptions []func(*Options)
// MinDelay is the minimum amount of time to delay between retries. If unset,
// RegistryRecordApprovedWaiter will use default minimum delay of 30 seconds. Note
// that MinDelay must resolve to a value lesser than or equal to the MaxDelay.
MinDelay time.Duration
// MaxDelay is the maximum amount of time to delay between retries. If unset or
// set to zero, RegistryRecordApprovedWaiter will use default max delay of 120
// seconds. Note that MaxDelay must resolve to value greater than or equal to the
// MinDelay.
MaxDelay time.Duration
// LogWaitAttempts is used to enable logging for waiter retry attempts
LogWaitAttempts bool
// Retryable is function that can be used to override the service defined
// waiter-behavior based on operation output, or returned error. This function is
// used by the waiter to decide if a state is retryable or a terminal state.
//
// By default service-modeled logic will populate this option. This option can
// thus be used to define a custom waiter state with fall-back to service-modeled
// waiter state mutators.The function returns an error in case of a failure state.
// In case of retry state, this function returns a bool value of true and nil
// error, while in case of success it returns a bool value of false and nil error.
Retryable func(context.Context, *GetRegistryRecordInput, *GetRegistryRecordOutput, error) (bool, error)
}
RegistryRecordApprovedWaiterOptions are waiter options for RegistryRecordApprovedWaiter
type ResolveEndpoint ¶
type ResolveEndpoint struct {
Resolver EndpointResolver
Options EndpointResolverOptions
}
func (*ResolveEndpoint) HandleSerialize ¶
func (m *ResolveEndpoint) HandleSerialize(ctx context.Context, in middleware.SerializeInput, next middleware.SerializeHandler) ( out middleware.SerializeOutput, metadata middleware.Metadata, err error, )
func (*ResolveEndpoint) ID ¶
func (*ResolveEndpoint) ID() string
type SubmitRegistryRecordForApprovalInput ¶
type SubmitRegistryRecordForApprovalInput struct {
// The identifier of the registry record to submit for approval (ARN or ID)
//
// This member is required.
RecordId *string
// The identifier of the registry containing the record (ARN or ID)
//
// This member is required.
RegistryId *string
// contains filtered or unexported fields
}
func (*SubmitRegistryRecordForApprovalInput) Serialize ¶
func (v *SubmitRegistryRecordForApprovalInput) Serialize(s smithy.ShapeSerializer)
func (*SubmitRegistryRecordForApprovalInput) SerializeMembers ¶
func (v *SubmitRegistryRecordForApprovalInput) SerializeMembers(s smithy.ShapeSerializer)
type SubmitRegistryRecordForApprovalOutput ¶
type SubmitRegistryRecordForApprovalOutput struct {
// The ARN of the registry record
//
// This member is required.
RecordArn *string
// The ID of the registry record
//
// This member is required.
RecordId *string
// The ARN of the registry
//
// This member is required.
RegistryArn *string
// The resulting status of the registry record
//
// This member is required.
Status types.RegistryRecordStatus
// The timestamp when the record was last updated
//
// This member is required.
UpdatedAt *time.Time
// Metadata pertaining to the operation's result.
ResultMetadata middleware.Metadata
// contains filtered or unexported fields
}
Response structure for submitting a registry record for approval
func (*SubmitRegistryRecordForApprovalOutput) Deserialize ¶
func (v *SubmitRegistryRecordForApprovalOutput) Deserialize(d smithy.ShapeDeserializer) error
func (*SubmitRegistryRecordForApprovalOutput) Serialize ¶
func (v *SubmitRegistryRecordForApprovalOutput) Serialize(s smithy.ShapeSerializer)
func (*SubmitRegistryRecordForApprovalOutput) SerializeMembers ¶
func (v *SubmitRegistryRecordForApprovalOutput) SerializeMembers(s smithy.ShapeSerializer)
type TagResourceInput ¶
type TagResourceInput struct {
// ARN of a taggable Agent Registry resource.
//
// This member is required.
ResourceArn *string
// A map of tag keys to tag values.
//
// This member is required.
Tags map[string]string
// contains filtered or unexported fields
}
func (*TagResourceInput) Serialize ¶
func (v *TagResourceInput) Serialize(s smithy.ShapeSerializer)
func (*TagResourceInput) SerializeMembers ¶
func (v *TagResourceInput) SerializeMembers(s smithy.ShapeSerializer)
type TagResourceOutput ¶
type TagResourceOutput struct {
// Metadata pertaining to the operation's result.
ResultMetadata middleware.Metadata
// contains filtered or unexported fields
}
func (*TagResourceOutput) Deserialize ¶
func (v *TagResourceOutput) Deserialize(d smithy.ShapeDeserializer) error
func (*TagResourceOutput) Serialize ¶
func (v *TagResourceOutput) Serialize(s smithy.ShapeSerializer)
func (*TagResourceOutput) SerializeMembers ¶
func (v *TagResourceOutput) SerializeMembers(s smithy.ShapeSerializer)
type UntagResourceInput ¶
type UntagResourceInput struct {
// ARN of a taggable Agent Registry resource.
//
// This member is required.
ResourceArn *string
// A list of tag keys.
//
// This member is required.
TagKeys []string
// contains filtered or unexported fields
}
func (*UntagResourceInput) Serialize ¶
func (v *UntagResourceInput) Serialize(s smithy.ShapeSerializer)
func (*UntagResourceInput) SerializeMembers ¶
func (v *UntagResourceInput) SerializeMembers(s smithy.ShapeSerializer)
type UntagResourceOutput ¶
type UntagResourceOutput struct {
// Metadata pertaining to the operation's result.
ResultMetadata middleware.Metadata
// contains filtered or unexported fields
}
func (*UntagResourceOutput) Deserialize ¶
func (v *UntagResourceOutput) Deserialize(d smithy.ShapeDeserializer) error
func (*UntagResourceOutput) Serialize ¶
func (v *UntagResourceOutput) Serialize(s smithy.ShapeSerializer)
func (*UntagResourceOutput) SerializeMembers ¶
func (v *UntagResourceOutput) SerializeMembers(s smithy.ShapeSerializer)
type UpdateRegistryInput ¶
type UpdateRegistryInput struct {
// The identifier of the registry to update (ARN or ID)
//
// This member is required.
RegistryId *string
// The updated approval configuration. The change applies only to records that
// move to PENDING_APPROVAL after the update; records already in PENDING_APPROVAL
// are unaffected.
ApprovalConfiguration *types.UpdatedApprovalConfiguration
// The updated description of the registry
Description *types.UpdatedDescription
// The updated discovery configuration. Changing the discovery authorization can
// break existing consumers that rely on the previous authorization type.
DiscoveryConfiguration *types.UpdatedDiscoveryConfiguration
// The updated name of the registry
Name *string
// contains filtered or unexported fields
}
Request structure for updating a registry
func (*UpdateRegistryInput) Serialize ¶
func (v *UpdateRegistryInput) Serialize(s smithy.ShapeSerializer)
func (*UpdateRegistryInput) SerializeMembers ¶
func (v *UpdateRegistryInput) SerializeMembers(s smithy.ShapeSerializer)
type UpdateRegistryOutput ¶
type UpdateRegistryOutput struct {
// The timestamp when the registry was created
//
// This member is required.
CreatedAt *time.Time
// The name of the registry
//
// This member is required.
Name *string
// The ARN of the registry
//
// This member is required.
RegistryArn *string
// The unique identifier of the registry
//
// This member is required.
RegistryId *string
// Current status of the registry
//
// This member is required.
Status types.RegistryStatus
// The timestamp when the registry was last updated
//
// This member is required.
UpdatedAt *time.Time
// Approval configuration for registry records
ApprovalConfiguration *types.ApprovalConfiguration
// The description of the registry
Description *string
// Discovery configuration for the registry
DiscoveryConfiguration *types.DiscoveryConfiguration
// The reason for the current status. Typically populated when the status
// indicates a failure state.
StatusReason *string
// Metadata pertaining to the operation's result.
ResultMetadata middleware.Metadata
// contains filtered or unexported fields
}
Response structure for updating a registry
func (*UpdateRegistryOutput) Deserialize ¶
func (v *UpdateRegistryOutput) Deserialize(d smithy.ShapeDeserializer) error
func (*UpdateRegistryOutput) Serialize ¶
func (v *UpdateRegistryOutput) Serialize(s smithy.ShapeSerializer)
func (*UpdateRegistryOutput) SerializeMembers ¶
func (v *UpdateRegistryOutput) SerializeMembers(s smithy.ShapeSerializer)
type UpdateRegistryRecordInput ¶
type UpdateRegistryRecordInput struct {
// The identifier of the registry record to update (ARN or ID)
//
// This member is required.
RecordId *string
// The identifier of the registry containing the record (ARN or ID)
//
// This member is required.
RegistryId *string
// The updated description of the registry record. Omit to leave the description
// unchanged; provide an empty wrapper to unset it.
Description *types.UpdatedDescription
// The updated typed descriptor content for the registry record. Omit to leave the
// descriptors unchanged.
Descriptors *types.UpdatedDescriptors
// The updated display name of the registry record. Omit to leave the display name
// unchanged; provide an empty wrapper to unset it.
DisplayName *types.UpdatedDisplayName
// The updated name of the registry record. Omit to leave the name unchanged.
Name *string
// The updated type of the registry record. Omit to leave the record type
// unchanged.
RecordType types.RecordType
// The updated version of the registry record. Omit to leave the version unchanged.
RecordVersion *string
// Whether to trigger synchronization of the record's descriptor content from its
// source
TriggerSynchronization *bool
// contains filtered or unexported fields
}
func (*UpdateRegistryRecordInput) Serialize ¶
func (v *UpdateRegistryRecordInput) Serialize(s smithy.ShapeSerializer)
func (*UpdateRegistryRecordInput) SerializeMembers ¶
func (v *UpdateRegistryRecordInput) SerializeMembers(s smithy.ShapeSerializer)
type UpdateRegistryRecordOutput ¶
type UpdateRegistryRecordOutput struct {
// The timestamp when the registry record was created.
//
// This member is required.
CreatedAt *time.Time
// The name of the registry record. Names are unique within a registry.
//
// This member is required.
Name *string
// The &ARN; of the registry record.
//
// This member is required.
RecordArn *string
// The unique identifier of the registry record.
//
// This member is required.
RecordId *string
// The type of the registry record, such as MCP, AGENT, SKILL, or CUSTOM.
//
// This member is required.
RecordType types.RecordType
// The &ARN; of the parent registry that owns the record.
//
// This member is required.
RegistryArn *string
// The lifecycle status of the registry record.
//
// This member is required.
Status types.RegistryRecordStatus
// The timestamp when the registry record was last updated.
//
// This member is required.
UpdatedAt *time.Time
// A description of the registry record.
Description *string
// The typed descriptors that define the content of the registry record.
Descriptors *types.Descriptors
// The human-readable display name of the registry record.
DisplayName *string
// The version identifier of the registry record.
RecordVersion *string
// The reason for the current status. Typically populated when the status
// indicates a failure state.
StatusReason *string
// Metadata pertaining to the operation's result.
ResultMetadata middleware.Metadata
// contains filtered or unexported fields
}
Response structure for updating a registry record
func (*UpdateRegistryRecordOutput) Deserialize ¶
func (v *UpdateRegistryRecordOutput) Deserialize(d smithy.ShapeDeserializer) error
func (*UpdateRegistryRecordOutput) Serialize ¶
func (v *UpdateRegistryRecordOutput) Serialize(s smithy.ShapeSerializer)
func (*UpdateRegistryRecordOutput) SerializeMembers ¶
func (v *UpdateRegistryRecordOutput) SerializeMembers(s smithy.ShapeSerializer)
type UpdateRegistryRecordStatusInput ¶
type UpdateRegistryRecordStatusInput struct {
// The identifier of the registry record to update the status of (ARN or ID)
//
// This member is required.
RecordId *string
// The identifier of the registry containing the record (ARN or ID)
//
// This member is required.
RegistryId *string
// The target status for the registry record
//
// This member is required.
Status types.RegistryRecordStatus
// The reason for the status change, for example why the record was approved,
// rejected, or deprecated
//
// This member is required.
StatusReason *string
// contains filtered or unexported fields
}
func (*UpdateRegistryRecordStatusInput) Serialize ¶
func (v *UpdateRegistryRecordStatusInput) Serialize(s smithy.ShapeSerializer)
func (*UpdateRegistryRecordStatusInput) SerializeMembers ¶
func (v *UpdateRegistryRecordStatusInput) SerializeMembers(s smithy.ShapeSerializer)
type UpdateRegistryRecordStatusOutput ¶
type UpdateRegistryRecordStatusOutput struct {
// The ARN of the registry record
//
// This member is required.
RecordArn *string
// The ID of the registry record
//
// This member is required.
RecordId *string
// The ARN of the registry
//
// This member is required.
RegistryArn *string
// The resulting status of the registry record
//
// This member is required.
Status types.RegistryRecordStatus
// The reason for the status change
//
// This member is required.
StatusReason *string
// The timestamp when the record was last updated
//
// This member is required.
UpdatedAt *time.Time
// Metadata pertaining to the operation's result.
ResultMetadata middleware.Metadata
// contains filtered or unexported fields
}
Response structure for updating a registry record status
func (*UpdateRegistryRecordStatusOutput) Deserialize ¶
func (v *UpdateRegistryRecordStatusOutput) Deserialize(d smithy.ShapeDeserializer) error
func (*UpdateRegistryRecordStatusOutput) Serialize ¶
func (v *UpdateRegistryRecordStatusOutput) Serialize(s smithy.ShapeSerializer)
func (*UpdateRegistryRecordStatusOutput) SerializeMembers ¶
func (v *UpdateRegistryRecordStatusOutput) SerializeMembers(s smithy.ShapeSerializer)
Source Files
¶
- api_client.go
- api_op_CreateRegistry.go
- api_op_CreateRegistryRecord.go
- api_op_DeleteRegistry.go
- api_op_DeleteRegistryRecord.go
- api_op_GetRegistry.go
- api_op_GetRegistryRecord.go
- api_op_ListRegistries.go
- api_op_ListRegistryRecords.go
- api_op_ListTagsForResource.go
- api_op_SubmitRegistryRecordForApproval.go
- api_op_TagResource.go
- api_op_UntagResource.go
- api_op_UpdateRegistry.go
- api_op_UpdateRegistryRecord.go
- api_op_UpdateRegistryRecordStatus.go
- auth.go
- common_serde.go
- doc.go
- endpoints.go
- go_module_metadata.go
- options.go
- type_registry.go
- validators.go