Documentation
¶
Index ¶
- type AccessDeniedException
- type AntipatternReportStatus
- type AntipatternSeveritySummary
- type AppType
- type ApplicationComponentCriteria
- type ApplicationComponentDetail
- type ApplicationComponentStrategy
- type ApplicationComponentSummary
- type ApplicationPreferences
- type AssessmentStatus
- type AssessmentSummary
- type AssociatedApplication
- type AwsManagedResources
- type AwsManagedTargetDestination
- type BusinessGoals
- type Collector
- type CollectorHealth
- type ConflictException
- type DataCollectionDetails
- type DataSourceType
- type DatabaseConfigDetail
- type DatabaseManagementPreference
- type DatabaseMigrationPreference
- type DatabaseMigrationPreferenceMemberHeterogeneous
- type DatabaseMigrationPreferenceMemberHomogeneous
- type DatabaseMigrationPreferenceMemberNoPreference
- type DatabasePreferences
- type Group
- type GroupName
- type Heterogeneous
- type HeterogeneousTargetDatabaseEngine
- type Homogeneous
- type HomogeneousTargetDatabaseEngine
- type ImportFileTaskInformation
- type ImportFileTaskStatus
- type InclusionStatus
- type InternalServerException
- type ManagementPreference
- type ManagementPreferenceMemberAwsManagedResources
- type ManagementPreferenceMemberNoPreference
- type ManagementPreferenceMemberSelfManageResources
- type NetworkInfo
- type NoDatabaseMigrationPreference
- type NoManagementPreference
- type NoPreferenceTargetDestination
- type OSInfo
- type OSType
- type OutputFormat
- type PrioritizeBusinessGoals
- type RecommendationReportDetails
- type RecommendationReportStatus
- type RecommendationSet
- type ResourceNotFoundException
- type ResourceSubType
- type RunTimeAssessmentStatus
- type S3Object
- type SelfManageResources
- type SelfManageTargetDestination
- type ServerCriteria
- type ServerDetail
- type ServerOsType
- type ServerStrategy
- type ServerSummary
- type ServiceLinkedRoleLockClientException
- type ServiceQuotaExceededException
- type Severity
- type SortOrder
- type SourceCode
- type SourceCodeRepository
- type SrcCodeOrDbAnalysisStatus
- type Strategy
- type StrategyOption
- type StrategyRecommendation
- type StrategySummary
- type SystemInfo
- type TargetDatabaseEngine
- type TargetDestination
- type ThrottlingException
- type TransformationTool
- type TransformationToolName
- type UnknownUnionMember
- type ValidationException
- type VersionControl
Examples ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AccessDeniedException ¶
type AccessDeniedException struct {
Message *string
// contains filtered or unexported fields
}
The AWS user account does not have permission to perform the action. Check the AWS Identity and Access Management (IAM) policy associated with this account.
func (*AccessDeniedException) Error ¶
func (e *AccessDeniedException) Error() string
func (*AccessDeniedException) ErrorCode ¶
func (e *AccessDeniedException) ErrorCode() string
func (*AccessDeniedException) ErrorFault ¶
func (e *AccessDeniedException) ErrorFault() smithy.ErrorFault
func (*AccessDeniedException) ErrorMessage ¶
func (e *AccessDeniedException) ErrorMessage() string
type AntipatternReportStatus ¶
type AntipatternReportStatus string
const ( AntipatternReportStatusFailed AntipatternReportStatus = "FAILED" AntipatternReportStatusInProgress AntipatternReportStatus = "IN_PROGRESS" AntipatternReportStatusSuccess AntipatternReportStatus = "SUCCESS" )
Enum values for AntipatternReportStatus
func (AntipatternReportStatus) Values ¶
func (AntipatternReportStatus) Values() []AntipatternReportStatus
Values returns all known values for AntipatternReportStatus. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type AntipatternSeveritySummary ¶
type AntipatternSeveritySummary struct {
// Contains the count of anti-patterns.
Count *int32
// Contains the severity of anti-patterns.
Severity Severity
// contains filtered or unexported fields
}
Contains the summary of anti-patterns and their severity.
type AppType ¶
type AppType string
type ApplicationComponentCriteria ¶
type ApplicationComponentCriteria string
const ( ApplicationComponentCriteriaNotDefined ApplicationComponentCriteria = "NOT_DEFINED" ApplicationComponentCriteriaAppName ApplicationComponentCriteria = "APP_NAME" ApplicationComponentCriteriaServerId ApplicationComponentCriteria = "SERVER_ID" ApplicationComponentCriteriaAppType ApplicationComponentCriteria = "APP_TYPE" ApplicationComponentCriteriaStrategy ApplicationComponentCriteria = "STRATEGY" ApplicationComponentCriteriaDestination ApplicationComponentCriteria = "DESTINATION" )
Enum values for ApplicationComponentCriteria
func (ApplicationComponentCriteria) Values ¶
func (ApplicationComponentCriteria) Values() []ApplicationComponentCriteria
Values returns all known values for ApplicationComponentCriteria. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type ApplicationComponentDetail ¶
type ApplicationComponentDetail struct {
// The status of analysis, if the application component has source code or an
// associated database.
AnalysisStatus SrcCodeOrDbAnalysisStatus
// The S3 bucket name and the Amazon S3 key name for the anti-pattern report.
AntipatternReportS3Object *S3Object
// The status of the anti-pattern report generation.
AntipatternReportStatus AntipatternReportStatus
// The status message for the anti-pattern.
AntipatternReportStatusMessage *string
// The type of application component.
AppType AppType
// The ID of the server that the application component is running on.
AssociatedServerId *string
// Configuration details for the database associated with the application
// component.
DatabaseConfigDetail *DatabaseConfigDetail
// The ID of the application component.
Id *string
// Indicates whether the application component has been included for server
// recommendation or not.
InclusionStatus InclusionStatus
// The timestamp of when the application component was assessed.
LastAnalyzedTimestamp *time.Time
// A list of anti-pattern severity summaries.
ListAntipatternSeveritySummary []AntipatternSeveritySummary
// Set to true if the application component is running on multiple servers.
MoreServerAssociationExists *bool
// The name of application component.
Name *string
// OS driver.
OsDriver *string
// OS version.
OsVersion *string
// The top recommendation set for the application component.
RecommendationSet *RecommendationSet
// The application component subtype.
ResourceSubType ResourceSubType
// Details about the source code repository associated with the application
// component.
SourceCodeRepositories []SourceCodeRepository
// A detailed description of the analysis status and any failure message.
StatusMessage *string
// contains filtered or unexported fields
}
Contains detailed information about an application component.
type ApplicationComponentStrategy ¶
type ApplicationComponentStrategy struct {
// Set to true if the recommendation is set as preferred.
IsPreferred *bool
// Strategy recommendation for the application component.
Recommendation *RecommendationSet
// The recommendation status of a strategy for an application component.
Status StrategyRecommendation
// contains filtered or unexported fields
}
Contains information about a strategy recommendation for an application component.
type ApplicationComponentSummary ¶
type ApplicationComponentSummary struct {
// Contains the name of application types.
AppType AppType
// Contains the count of application type.
Count *int32
// contains filtered or unexported fields
}
Contains the summary of application components.
type ApplicationPreferences ¶
type ApplicationPreferences struct {
// Application preferences that you specify to prefer managed environment.
ManagementPreference ManagementPreference
// contains filtered or unexported fields
}
Application preferences that you specify.
type AssessmentStatus ¶
type AssessmentStatus string
const ( AssessmentStatusInProgress AssessmentStatus = "IN_PROGRESS" AssessmentStatusComplete AssessmentStatus = "COMPLETE" AssessmentStatusFailed AssessmentStatus = "FAILED" AssessmentStatusStopped AssessmentStatus = "STOPPED" )
Enum values for AssessmentStatus
func (AssessmentStatus) Values ¶
func (AssessmentStatus) Values() []AssessmentStatus
Values returns all known values for AssessmentStatus. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type AssessmentSummary ¶
type AssessmentSummary struct {
// The Amazon S3 object containing the anti-pattern report.
AntipatternReportS3Object *S3Object
// The status of the anti-pattern report.
AntipatternReportStatus AntipatternReportStatus
// The status message of the anti-pattern report.
AntipatternReportStatusMessage *string
// The time the assessment was performed.
LastAnalyzedTimestamp *time.Time
// List of AntipatternSeveritySummary.
ListAntipatternSeveritySummary []AntipatternSeveritySummary
// List of ApplicationComponentStrategySummary.
ListApplicationComponentStrategySummary []StrategySummary
// List of ApplicationComponentSummary.
ListApplicationComponentSummary []ApplicationComponentSummary
// List of ServerStrategySummary.
ListServerStrategySummary []StrategySummary
// List of ServerSummary.
ListServerSummary []ServerSummary
// contains filtered or unexported fields
}
Contains the summary of the assessment results.
type AssociatedApplication ¶
type AssociatedApplication struct {
// ID of the application as defined in Application Discovery Service.
Id *string
// Name of the application as defined in Application Discovery Service.
Name *string
// contains filtered or unexported fields
}
Object containing details about applications as defined in Application Discovery Service.
type AwsManagedResources ¶
type AwsManagedResources struct {
// The choice of application destination that you specify.
//
// This member is required.
TargetDestination []AwsManagedTargetDestination
// contains filtered or unexported fields
}
Object containing the choice of application destination that you specify.
type AwsManagedTargetDestination ¶
type AwsManagedTargetDestination string
const ( AwsManagedTargetDestinationNoneSpecified AwsManagedTargetDestination = "None specified" AwsManagedTargetDestinationAwsElasticBeanstalk AwsManagedTargetDestination = "AWS Elastic BeanStalk" AwsManagedTargetDestinationAwsFargate AwsManagedTargetDestination = "AWS Fargate" )
Enum values for AwsManagedTargetDestination
func (AwsManagedTargetDestination) Values ¶
func (AwsManagedTargetDestination) Values() []AwsManagedTargetDestination
Values returns all known values for AwsManagedTargetDestination. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type BusinessGoals ¶
type BusinessGoals struct {
// Business goal to reduce license costs.
LicenseCostReduction *int32
// Business goal to modernize infrastructure by moving to cloud native
// technologies.
ModernizeInfrastructureWithCloudNativeTechnologies *int32
// Business goal to reduce the operational overhead on the team by moving into
// managed services.
ReduceOperationalOverheadWithManagedServices *int32
// Business goal to achieve migration at a fast pace.
SpeedOfMigration *int32
// contains filtered or unexported fields
}
Business goals that you specify.
type Collector ¶
type Collector struct {
// Indicates the health of a collector.
CollectorHealth CollectorHealth
// The ID of the collector.
CollectorId *string
// Current version of the collector that is running in the environment that you
// specify.
CollectorVersion *string
// Hostname of the server that is hosting the collector.
HostName *string
// IP address of the server that is hosting the collector.
IpAddress *string
// Time when the collector last pinged the service.
LastActivityTimeStamp *string
// Time when the collector registered with the service.
RegisteredTimeStamp *string
// contains filtered or unexported fields
}
Process data collector that runs in the environment that you specify.
type CollectorHealth ¶
type CollectorHealth string
const ( CollectorHealthCollectorHealthy CollectorHealth = "COLLECTOR_HEALTHY" CollectorHealthCollectorUnhealthy CollectorHealth = "COLLECTOR_UNHEALTHY" )
Enum values for CollectorHealth
func (CollectorHealth) Values ¶
func (CollectorHealth) Values() []CollectorHealth
Values returns all known values for CollectorHealth. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type ConflictException ¶
type ConflictException struct {
Message *string
// contains filtered or unexported fields
}
Exception to indicate that there is an ongoing task when a new task is created. Return when once the existing tasks are complete.
func (*ConflictException) Error ¶
func (e *ConflictException) Error() string
func (*ConflictException) ErrorCode ¶
func (e *ConflictException) ErrorCode() string
func (*ConflictException) ErrorFault ¶
func (e *ConflictException) ErrorFault() smithy.ErrorFault
func (*ConflictException) ErrorMessage ¶
func (e *ConflictException) ErrorMessage() string
type DataCollectionDetails ¶
type DataCollectionDetails struct {
// The time the assessment completes.
CompletionTime *time.Time
// The number of failed servers in the assessment.
Failed *int32
// The number of servers with the assessment status IN_PROGESS.
InProgress *int32
// The total number of servers in the assessment.
Servers *int32
// The start time of assessment.
StartTime *time.Time
// The status of the assessment.
Status AssessmentStatus
// The number of successful servers in the assessment.
Success *int32
// contains filtered or unexported fields
}
Detailed information about an assessment.
type DataSourceType ¶
type DataSourceType string
const ( DataSourceTypeAds DataSourceType = "ApplicationDiscoveryService" DataSourceTypeMpa DataSourceType = "MPA" )
Enum values for DataSourceType
func (DataSourceType) Values ¶
func (DataSourceType) Values() []DataSourceType
Values returns all known values for DataSourceType. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type DatabaseConfigDetail ¶
type DatabaseConfigDetail struct {
// AWS Secrets Manager key that holds the credentials that you use to connect to a
// database.
SecretName *string
// contains filtered or unexported fields
}
Configuration information used for assessing databases.
type DatabaseManagementPreference ¶
type DatabaseManagementPreference string
const ( DatabaseManagementPreferenceAwsManaged DatabaseManagementPreference = "AWS-managed" DatabaseManagementPreferenceSelfManage DatabaseManagementPreference = "Self-manage" DatabaseManagementPreferenceNoPreference DatabaseManagementPreference = "No preference" )
Enum values for DatabaseManagementPreference
func (DatabaseManagementPreference) Values ¶
func (DatabaseManagementPreference) Values() []DatabaseManagementPreference
Values returns all known values for DatabaseManagementPreference. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type DatabaseMigrationPreference ¶
type DatabaseMigrationPreference interface {
// contains filtered or unexported methods
}
Preferences for migrating a database to AWS.
The following types satisfy this interface:
DatabaseMigrationPreferenceMemberHeterogeneous DatabaseMigrationPreferenceMemberHomogeneous DatabaseMigrationPreferenceMemberNoPreference
Example (OutputUsage) ¶
package main
import (
"fmt"
"github.com/aws/aws-sdk-go-v2/service/migrationhubstrategy/types"
)
func main() {
var union types.DatabaseMigrationPreference
// type switches can be used to check the union value
switch v := union.(type) {
case *types.DatabaseMigrationPreferenceMemberHeterogeneous:
_ = v.Value // Value is types.Heterogeneous
case *types.DatabaseMigrationPreferenceMemberHomogeneous:
_ = v.Value // Value is types.Homogeneous
case *types.DatabaseMigrationPreferenceMemberNoPreference:
_ = v.Value // Value is types.NoDatabaseMigrationPreference
case *types.UnknownUnionMember:
fmt.Println("unknown tag:", v.Tag)
default:
fmt.Println("union is nil or unknown type")
}
}
Output:
type DatabaseMigrationPreferenceMemberHeterogeneous ¶
type DatabaseMigrationPreferenceMemberHeterogeneous struct {
Value Heterogeneous
// contains filtered or unexported fields
}
Indicates whether you are interested in moving from one type of database to another. For example, from SQL Server to Amazon Aurora MySQL-Compatible Edition.
type DatabaseMigrationPreferenceMemberHomogeneous ¶
type DatabaseMigrationPreferenceMemberHomogeneous struct {
Value Homogeneous
// contains filtered or unexported fields
}
Indicates whether you are interested in moving to the same type of database into AWS. For example, from SQL Server in your environment to SQL Server on AWS.
type DatabaseMigrationPreferenceMemberNoPreference ¶
type DatabaseMigrationPreferenceMemberNoPreference struct {
Value NoDatabaseMigrationPreference
// contains filtered or unexported fields
}
Indicated that you do not prefer heterogeneous or homogeneous.
type DatabasePreferences ¶
type DatabasePreferences struct {
// Specifies whether you're interested in self-managed databases or databases
// managed by AWS.
DatabaseManagementPreference DatabaseManagementPreference
// Specifies your preferred migration path.
DatabaseMigrationPreference DatabaseMigrationPreference
// contains filtered or unexported fields
}
Preferences on managing your databases on AWS.
type Group ¶
type Group struct {
// The key of the specific import group.
Name GroupName
// The value of the specific import group.
Value *string
// contains filtered or unexported fields
}
The object containing information about distinct imports or groups for Strategy Recommendations.
type GroupName ¶
type GroupName string
const (
GroupNameExternalId GroupName = "ExternalId"
)
Enum values for GroupName
type Heterogeneous ¶
type Heterogeneous struct {
// The target database engine for heterogeneous database migration preference.
//
// This member is required.
TargetDatabaseEngine []HeterogeneousTargetDatabaseEngine
// contains filtered or unexported fields
}
The object containing details about heterogeneous database preferences.
type HeterogeneousTargetDatabaseEngine ¶
type HeterogeneousTargetDatabaseEngine string
const ( HeterogeneousTargetDatabaseEngineNoneSpecified HeterogeneousTargetDatabaseEngine = "None specified" HeterogeneousTargetDatabaseEngineAmazonAurora HeterogeneousTargetDatabaseEngine = "Amazon Aurora" HeterogeneousTargetDatabaseEngineAwsPostgresql HeterogeneousTargetDatabaseEngine = "AWS PostgreSQL" HeterogeneousTargetDatabaseEngineMysql HeterogeneousTargetDatabaseEngine = "MySQL" HeterogeneousTargetDatabaseEngineMicrosoftSqlServer HeterogeneousTargetDatabaseEngine = "Microsoft SQL Server" HeterogeneousTargetDatabaseEngineOracleDatabase HeterogeneousTargetDatabaseEngine = "Oracle Database" HeterogeneousTargetDatabaseEngineMariaDb HeterogeneousTargetDatabaseEngine = "MariaDB" HeterogeneousTargetDatabaseEngineSap HeterogeneousTargetDatabaseEngine = "SAP" HeterogeneousTargetDatabaseEngineDb2Luw HeterogeneousTargetDatabaseEngine = "Db2 LUW" HeterogeneousTargetDatabaseEngineMongoDb HeterogeneousTargetDatabaseEngine = "MongoDB" )
Enum values for HeterogeneousTargetDatabaseEngine
func (HeterogeneousTargetDatabaseEngine) Values ¶
func (HeterogeneousTargetDatabaseEngine) Values() []HeterogeneousTargetDatabaseEngine
Values returns all known values for HeterogeneousTargetDatabaseEngine. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type Homogeneous ¶
type Homogeneous struct {
// The target database engine for homogeneous database migration preferences.
TargetDatabaseEngine []HomogeneousTargetDatabaseEngine
// contains filtered or unexported fields
}
The object containing details about homogeneous database preferences.
type HomogeneousTargetDatabaseEngine ¶
type HomogeneousTargetDatabaseEngine string
const (
HomogeneousTargetDatabaseEngineNoneSpecified HomogeneousTargetDatabaseEngine = "None specified"
)
Enum values for HomogeneousTargetDatabaseEngine
func (HomogeneousTargetDatabaseEngine) Values ¶
func (HomogeneousTargetDatabaseEngine) Values() []HomogeneousTargetDatabaseEngine
Values returns all known values for HomogeneousTargetDatabaseEngine. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type ImportFileTaskInformation ¶
type ImportFileTaskInformation struct {
// The time that the import task completes.
CompletionTime *time.Time
// The ID of the import file task.
Id *string
// The name of the import task given in StartImportFileTask.
ImportName *string
// The S3 bucket where the import file is located.
InputS3Bucket *string
// The Amazon S3 key name of the import file.
InputS3Key *string
// The number of records that failed to be imported.
NumberOfRecordsFailed *int32
// The number of records successfully imported.
NumberOfRecordsSuccess *int32
// Start time of the import task.
StartTime *time.Time
// Status of import file task.
Status ImportFileTaskStatus
// The S3 bucket name for status report of import task.
StatusReportS3Bucket *string
// The Amazon S3 key name for status report of import task. The report contains
// details about whether each record imported successfully or why it did not.
StatusReportS3Key *string
// contains filtered or unexported fields
}
Information about the import file tasks you request.
type ImportFileTaskStatus ¶
type ImportFileTaskStatus string
const ( ImportFileTaskStatusImportInProgress ImportFileTaskStatus = "ImportInProgress" ImportFileTaskStatusImportFailed ImportFileTaskStatus = "ImportFailed" ImportFileTaskStatusImportPartialSuccess ImportFileTaskStatus = "ImportPartialSuccess" ImportFileTaskStatusImportSuccess ImportFileTaskStatus = "ImportSuccess" ImportFileTaskStatusDeleteInProgress ImportFileTaskStatus = "DeleteInProgress" ImportFileTaskStatusDeleteFailed ImportFileTaskStatus = "DeleteFailed" ImportFileTaskStatusDeletePartialSuccess ImportFileTaskStatus = "DeletePartialSuccess" ImportFileTaskStatusDeleteSuccess ImportFileTaskStatus = "DeleteSuccess" )
Enum values for ImportFileTaskStatus
func (ImportFileTaskStatus) Values ¶
func (ImportFileTaskStatus) Values() []ImportFileTaskStatus
Values returns all known values for ImportFileTaskStatus. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type InclusionStatus ¶
type InclusionStatus string
const ( InclusionStatusExcludeFromRecommendation InclusionStatus = "excludeFromAssessment" InclusionStatusIncludeInRecommendation InclusionStatus = "includeInAssessment" )
Enum values for InclusionStatus
func (InclusionStatus) Values ¶
func (InclusionStatus) Values() []InclusionStatus
Values returns all known values for InclusionStatus. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type InternalServerException ¶
type InternalServerException struct {
Message *string
// contains filtered or unexported fields
}
The server experienced an internal error. Try again.
func (*InternalServerException) Error ¶
func (e *InternalServerException) Error() string
func (*InternalServerException) ErrorCode ¶
func (e *InternalServerException) ErrorCode() string
func (*InternalServerException) ErrorFault ¶
func (e *InternalServerException) ErrorFault() smithy.ErrorFault
func (*InternalServerException) ErrorMessage ¶
func (e *InternalServerException) ErrorMessage() string
type ManagementPreference ¶
type ManagementPreference interface {
// contains filtered or unexported methods
}
Preferences for migrating an application to AWS.
The following types satisfy this interface:
ManagementPreferenceMemberAwsManagedResources ManagementPreferenceMemberNoPreference ManagementPreferenceMemberSelfManageResources
Example (OutputUsage) ¶
package main
import (
"fmt"
"github.com/aws/aws-sdk-go-v2/service/migrationhubstrategy/types"
)
func main() {
var union types.ManagementPreference
// type switches can be used to check the union value
switch v := union.(type) {
case *types.ManagementPreferenceMemberAwsManagedResources:
_ = v.Value // Value is types.AwsManagedResources
case *types.ManagementPreferenceMemberNoPreference:
_ = v.Value // Value is types.NoManagementPreference
case *types.ManagementPreferenceMemberSelfManageResources:
_ = v.Value // Value is types.SelfManageResources
case *types.UnknownUnionMember:
fmt.Println("unknown tag:", v.Tag)
default:
fmt.Println("union is nil or unknown type")
}
}
Output:
type ManagementPreferenceMemberAwsManagedResources ¶
type ManagementPreferenceMemberAwsManagedResources struct {
Value AwsManagedResources
// contains filtered or unexported fields
}
Indicates interest in solutions that are managed by AWS.
type ManagementPreferenceMemberNoPreference ¶
type ManagementPreferenceMemberNoPreference struct {
Value NoManagementPreference
// contains filtered or unexported fields
}
No specific preference.
type ManagementPreferenceMemberSelfManageResources ¶
type ManagementPreferenceMemberSelfManageResources struct {
Value SelfManageResources
// contains filtered or unexported fields
}
Indicates interest in managing your own resources on AWS.
type NetworkInfo ¶
type NetworkInfo struct {
// Information about the name of the interface of the server for which the
// assessment was run.
//
// This member is required.
InterfaceName *string
// Information about the IP address of the server for which the assessment was run.
//
// This member is required.
IpAddress *string
// Information about the MAC address of the server for which the assessment was
// run.
//
// This member is required.
MacAddress *string
// Information about the subnet mask of the server for which the assessment was
// run.
//
// This member is required.
NetMask *string
// contains filtered or unexported fields
}
Information about the server's network for which the assessment was run.
type NoDatabaseMigrationPreference ¶
type NoDatabaseMigrationPreference struct {
// The target database engine for database migration preference that you specify.
//
// This member is required.
TargetDatabaseEngine []TargetDatabaseEngine
// contains filtered or unexported fields
}
The object containing details about database migration preferences, when you have no particular preference.
type NoManagementPreference ¶
type NoManagementPreference struct {
// The choice of application destination that you specify.
//
// This member is required.
TargetDestination []NoPreferenceTargetDestination
// contains filtered or unexported fields
}
Object containing the choice of application destination that you specify.
type NoPreferenceTargetDestination ¶
type NoPreferenceTargetDestination string
const ( NoPreferenceTargetDestinationNoneSpecified NoPreferenceTargetDestination = "None specified" NoPreferenceTargetDestinationAwsElasticBeanstalk NoPreferenceTargetDestination = "AWS Elastic BeanStalk" NoPreferenceTargetDestinationAwsFargate NoPreferenceTargetDestination = "AWS Fargate" NoPreferenceTargetDestinationAmazonElasticCloudCompute NoPreferenceTargetDestination = "Amazon Elastic Cloud Compute (EC2)" NoPreferenceTargetDestinationAmazonElasticContainerService NoPreferenceTargetDestination = "Amazon Elastic Container Service (ECS)" NoPreferenceTargetDestinationAmazonElasticKubernetesService NoPreferenceTargetDestination = "Amazon Elastic Kubernetes Service (EKS)" )
Enum values for NoPreferenceTargetDestination
func (NoPreferenceTargetDestination) Values ¶
func (NoPreferenceTargetDestination) Values() []NoPreferenceTargetDestination
Values returns all known values for NoPreferenceTargetDestination. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type OSInfo ¶
type OSInfo struct {
// Information about the type of operating system.
Type OSType
// Information about the version of operating system.
Version *string
// contains filtered or unexported fields
}
Information about the operating system.
type OutputFormat ¶
type OutputFormat string
const ( OutputFormatExcel OutputFormat = "Excel" OutputFormatJson OutputFormat = "Json" )
Enum values for OutputFormat
func (OutputFormat) Values ¶
func (OutputFormat) Values() []OutputFormat
Values returns all known values for OutputFormat. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type PrioritizeBusinessGoals ¶
type PrioritizeBusinessGoals struct {
// Rank of business goals based on priority.
BusinessGoals *BusinessGoals
// contains filtered or unexported fields
}
Rank of business goals based on priority.
type RecommendationReportDetails ¶
type RecommendationReportDetails struct {
// The time that the recommendation report generation task completes.
CompletionTime *time.Time
// The S3 bucket where the report file is located.
S3Bucket *string
// The Amazon S3 key name of the report file.
S3Keys []string
// The time that the recommendation report generation task starts.
StartTime *time.Time
// The status of the recommendation report generation task.
Status RecommendationReportStatus
// The status message for recommendation report generation.
StatusMessage *string
// contains filtered or unexported fields
}
Contains detailed information about a recommendation report.
type RecommendationReportStatus ¶
type RecommendationReportStatus string
const ( RecommendationReportStatusFailed RecommendationReportStatus = "FAILED" RecommendationReportStatusInProgress RecommendationReportStatus = "IN_PROGRESS" RecommendationReportStatusSuccess RecommendationReportStatus = "SUCCESS" )
Enum values for RecommendationReportStatus
func (RecommendationReportStatus) Values ¶
func (RecommendationReportStatus) Values() []RecommendationReportStatus
Values returns all known values for RecommendationReportStatus. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type RecommendationSet ¶
type RecommendationSet struct {
// The recommended strategy.
Strategy Strategy
// The recommended target destination.
TargetDestination TargetDestination
// The target destination for the recommendation set.
TransformationTool *TransformationTool
// contains filtered or unexported fields
}
Contains a recommendation set.
type ResourceNotFoundException ¶
type ResourceNotFoundException struct {
Message *string
// contains filtered or unexported fields
}
The specified ID in the request is not found.
func (*ResourceNotFoundException) Error ¶
func (e *ResourceNotFoundException) Error() string
func (*ResourceNotFoundException) ErrorCode ¶
func (e *ResourceNotFoundException) ErrorCode() string
func (*ResourceNotFoundException) ErrorFault ¶
func (e *ResourceNotFoundException) ErrorFault() smithy.ErrorFault
func (*ResourceNotFoundException) ErrorMessage ¶
func (e *ResourceNotFoundException) ErrorMessage() string
type ResourceSubType ¶
type ResourceSubType string
const ( ResourceSubTypeDatabase ResourceSubType = "Database" ResourceSubTypeProcess ResourceSubType = "Process" ResourceSubTypeDatabaseProcess ResourceSubType = "DatabaseProcess" )
Enum values for ResourceSubType
func (ResourceSubType) Values ¶
func (ResourceSubType) Values() []ResourceSubType
Values returns all known values for ResourceSubType. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type RunTimeAssessmentStatus ¶
type RunTimeAssessmentStatus string
const ( RunTimeAssessmentStatusDcToBeScheduled RunTimeAssessmentStatus = "dataCollectionTaskToBeScheduled" RunTimeAssessmentStatusDcReqSent RunTimeAssessmentStatus = "dataCollectionTaskScheduled" RunTimeAssessmentStatusDcStarted RunTimeAssessmentStatus = "dataCollectionTaskStarted" RunTimeAssessmentStatusDcStopped RunTimeAssessmentStatus = "dataCollectionTaskStopped" RunTimeAssessmentStatusDcSuccess RunTimeAssessmentStatus = "dataCollectionTaskSuccess" RunTimeAssessmentStatusDcFailed RunTimeAssessmentStatus = "dataCollectionTaskFailed" RunTimeAssessmentStatusDcPartialSuccess RunTimeAssessmentStatus = "dataCollectionTaskPartialSuccess" )
Enum values for RunTimeAssessmentStatus
func (RunTimeAssessmentStatus) Values ¶
func (RunTimeAssessmentStatus) Values() []RunTimeAssessmentStatus
Values returns all known values for RunTimeAssessmentStatus. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type S3Object ¶
type S3Object struct {
// The S3 bucket name.
S3Bucket *string
// The Amazon S3 key name.
S3key *string
// contains filtered or unexported fields
}
Contains the S3 bucket name and the Amazon S3 key name.
type SelfManageResources ¶
type SelfManageResources struct {
// Self-managed resources target destination.
//
// This member is required.
TargetDestination []SelfManageTargetDestination
// contains filtered or unexported fields
}
Self-managed resources.
type SelfManageTargetDestination ¶
type SelfManageTargetDestination string
const ( SelfManageTargetDestinationNoneSpecified SelfManageTargetDestination = "None specified" SelfManageTargetDestinationAmazonElasticCloudCompute SelfManageTargetDestination = "Amazon Elastic Cloud Compute (EC2)" SelfManageTargetDestinationAmazonElasticContainerService SelfManageTargetDestination = "Amazon Elastic Container Service (ECS)" SelfManageTargetDestinationAmazonElasticKubernetesService SelfManageTargetDestination = "Amazon Elastic Kubernetes Service (EKS)" )
Enum values for SelfManageTargetDestination
func (SelfManageTargetDestination) Values ¶
func (SelfManageTargetDestination) Values() []SelfManageTargetDestination
Values returns all known values for SelfManageTargetDestination. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type ServerCriteria ¶
type ServerCriteria string
const ( ServerCriteriaNotDefined ServerCriteria = "NOT_DEFINED" ServerCriteriaOsName ServerCriteria = "OS_NAME" ServerCriteriaStrategy ServerCriteria = "STRATEGY" ServerCriteriaDestination ServerCriteria = "DESTINATION" ServerCriteriaServerId ServerCriteria = "SERVER_ID" )
Enum values for ServerCriteria
func (ServerCriteria) Values ¶
func (ServerCriteria) Values() []ServerCriteria
Values returns all known values for ServerCriteria. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type ServerDetail ¶
type ServerDetail struct {
// The S3 bucket name and Amazon S3 key name for anti-pattern report.
AntipatternReportS3Object *S3Object
// The status of the anti-pattern report generation.
AntipatternReportStatus AntipatternReportStatus
// A message about the status of the anti-pattern report generation.
AntipatternReportStatusMessage *string
// A list of strategy summaries.
ApplicationComponentStrategySummary []StrategySummary
// The status of assessment for the server.
DataCollectionStatus RunTimeAssessmentStatus
// The server ID.
Id *string
// The timestamp of when the server was assessed.
LastAnalyzedTimestamp *time.Time
// A list of anti-pattern severity summaries.
ListAntipatternSeveritySummary []AntipatternSeveritySummary
// The name of the server.
Name *string
// A set of recommendations.
RecommendationSet *RecommendationSet
// The type of server.
ServerType *string
// A message about the status of data collection, which contains detailed
// descriptions of any error messages.
StatusMessage *string
// System information about the server.
SystemInfo *SystemInfo
// contains filtered or unexported fields
}
Detailed information about a server.
type ServerOsType ¶
type ServerOsType string
const ( ServerOsTypeWindowsServer ServerOsType = "WindowsServer" ServerOsTypeAmazonLinux ServerOsType = "AmazonLinux" ServerOsTypeEndOfSupportWindowsServer ServerOsType = "EndOfSupportWindowsServer" ServerOsTypeRedhat ServerOsType = "Redhat" ServerOsTypeOther ServerOsType = "Other" )
Enum values for ServerOsType
func (ServerOsType) Values ¶
func (ServerOsType) Values() []ServerOsType
Values returns all known values for ServerOsType. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type ServerStrategy ¶
type ServerStrategy struct {
// Set to true if the recommendation is set as preferred.
IsPreferred *bool
// The number of application components with this strategy recommendation running
// on the server.
NumberOfApplicationComponents *int32
// Strategy recommendation for the server.
Recommendation *RecommendationSet
// The recommendation status of the strategy for the server.
Status StrategyRecommendation
// contains filtered or unexported fields
}
Contains information about a strategy recommendation for a server.
type ServerSummary ¶
type ServerSummary struct {
// Number of servers.
Count *int32
// Type of operating system for the servers.
ServerOsType ServerOsType
// contains filtered or unexported fields
}
Object containing details about the servers imported by Application Discovery Service
type ServiceLinkedRoleLockClientException ¶
type ServiceLinkedRoleLockClientException struct {
Message *string
// contains filtered or unexported fields
}
Exception to indicate that the service-linked role (SLR) is locked.
func (*ServiceLinkedRoleLockClientException) Error ¶
func (e *ServiceLinkedRoleLockClientException) Error() string
func (*ServiceLinkedRoleLockClientException) ErrorCode ¶
func (e *ServiceLinkedRoleLockClientException) ErrorCode() string
func (*ServiceLinkedRoleLockClientException) ErrorFault ¶
func (e *ServiceLinkedRoleLockClientException) ErrorFault() smithy.ErrorFault
func (*ServiceLinkedRoleLockClientException) ErrorMessage ¶
func (e *ServiceLinkedRoleLockClientException) ErrorMessage() string
type ServiceQuotaExceededException ¶
type ServiceQuotaExceededException struct {
Message *string
// contains filtered or unexported fields
}
The AWS account has reached its quota of imports. Contact AWS Support to increase the quota for this account.
func (*ServiceQuotaExceededException) Error ¶
func (e *ServiceQuotaExceededException) Error() string
func (*ServiceQuotaExceededException) ErrorCode ¶
func (e *ServiceQuotaExceededException) ErrorCode() string
func (*ServiceQuotaExceededException) ErrorFault ¶
func (e *ServiceQuotaExceededException) ErrorFault() smithy.ErrorFault
func (*ServiceQuotaExceededException) ErrorMessage ¶
func (e *ServiceQuotaExceededException) ErrorMessage() string
type Severity ¶
type Severity string
type SourceCode ¶
type SourceCode struct {
// The repository name for the source code.
Location *string
// The branch of the source code.
SourceVersion *string
// The type of repository to use for the source code.
VersionControl VersionControl
// contains filtered or unexported fields
}
Object containing source code information that is linked to an application component.
type SourceCodeRepository ¶
type SourceCodeRepository struct {
// The branch of the source code.
Branch *string
// The repository name for the source code.
Repository *string
// The type of repository to use for the source code.
VersionControlType *string
// contains filtered or unexported fields
}
Object containing source code information that is linked to an application component.
type SrcCodeOrDbAnalysisStatus ¶
type SrcCodeOrDbAnalysisStatus string
const ( SrcCodeOrDbAnalysisStatusAnalysisToBeScheduled SrcCodeOrDbAnalysisStatus = "ANALYSIS_TO_BE_SCHEDULED" SrcCodeOrDbAnalysisStatusAnalysisStarted SrcCodeOrDbAnalysisStatus = "ANALYSIS_STARTED" SrcCodeOrDbAnalysisStatusAnalysisSuccess SrcCodeOrDbAnalysisStatus = "ANALYSIS_SUCCESS" SrcCodeOrDbAnalysisStatusAnalysisFailed SrcCodeOrDbAnalysisStatus = "ANALYSIS_FAILED" )
Enum values for SrcCodeOrDbAnalysisStatus
func (SrcCodeOrDbAnalysisStatus) Values ¶
func (SrcCodeOrDbAnalysisStatus) Values() []SrcCodeOrDbAnalysisStatus
Values returns all known values for SrcCodeOrDbAnalysisStatus. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type Strategy ¶
type Strategy string
const ( StrategyRehost Strategy = "Rehost" StrategyRetirement Strategy = "Retirement" StrategyRefactor Strategy = "Refactor" StrategyReplatform Strategy = "Replatform" StrategyRetain Strategy = "Retain" StrategyRelocate Strategy = "Relocate" StrategyRepurchase Strategy = "Repurchase" )
Enum values for Strategy
type StrategyOption ¶
type StrategyOption struct {
// Indicates if a specific strategy is preferred for the application component.
IsPreferred *bool
// Type of transformation. For example, Rehost, Replatform, and so on.
Strategy Strategy
// Destination information about where the application component can migrate to.
// For example, EC2, ECS, and so on.
TargetDestination TargetDestination
// The name of the tool that can be used to transform an application component
// using this strategy.
ToolName TransformationToolName
// contains filtered or unexported fields
}
Information about all the available strategy options for migrating and modernizing an application component.
type StrategyRecommendation ¶
type StrategyRecommendation string
const ( StrategyRecommendationRecommended StrategyRecommendation = "recommended" StrategyRecommendationViableOption StrategyRecommendation = "viableOption" StrategyRecommendationNotRecommended StrategyRecommendation = "notRecommended" )
Enum values for StrategyRecommendation
func (StrategyRecommendation) Values ¶
func (StrategyRecommendation) Values() []StrategyRecommendation
Values returns all known values for StrategyRecommendation. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type StrategySummary ¶
type StrategySummary struct {
// The count of recommendations per strategy.
Count *int32
// The name of recommended strategy.
Strategy Strategy
// contains filtered or unexported fields
}
Object containing the summary of the strategy recommendations.
type SystemInfo ¶
type SystemInfo struct {
// CPU architecture type for the server.
CpuArchitecture *string
// File system type for the server.
FileSystemType *string
// Networking information related to a server.
NetworkInfoList []NetworkInfo
// Operating system corresponding to a server.
OsInfo *OSInfo
// contains filtered or unexported fields
}
Information about the server that hosts application components.
type TargetDatabaseEngine ¶
type TargetDatabaseEngine string
const ( TargetDatabaseEngineNoneSpecified TargetDatabaseEngine = "None specified" TargetDatabaseEngineAmazonAurora TargetDatabaseEngine = "Amazon Aurora" TargetDatabaseEngineAwsPostgresql TargetDatabaseEngine = "AWS PostgreSQL" TargetDatabaseEngineMysql TargetDatabaseEngine = "MySQL" TargetDatabaseEngineMicrosoftSqlServer TargetDatabaseEngine = "Microsoft SQL Server" TargetDatabaseEngineOracleDatabase TargetDatabaseEngine = "Oracle Database" TargetDatabaseEngineMariaDb TargetDatabaseEngine = "MariaDB" TargetDatabaseEngineSap TargetDatabaseEngine = "SAP" TargetDatabaseEngineDb2Luw TargetDatabaseEngine = "Db2 LUW" TargetDatabaseEngineMongoDb TargetDatabaseEngine = "MongoDB" )
Enum values for TargetDatabaseEngine
func (TargetDatabaseEngine) Values ¶
func (TargetDatabaseEngine) Values() []TargetDatabaseEngine
Values returns all known values for TargetDatabaseEngine. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type TargetDestination ¶
type TargetDestination string
const ( TargetDestinationNoneSpecified TargetDestination = "None specified" TargetDestinationAwsElasticBeanstalk TargetDestination = "AWS Elastic BeanStalk" TargetDestinationAwsFargate TargetDestination = "AWS Fargate" TargetDestinationAmazonElasticCloudCompute TargetDestination = "Amazon Elastic Cloud Compute (EC2)" TargetDestinationAmazonElasticContainerService TargetDestination = "Amazon Elastic Container Service (ECS)" TargetDestinationAmazonElasticKubernetesService TargetDestination = "Amazon Elastic Kubernetes Service (EKS)" TargetDestinationAuroraMysql TargetDestination = "Aurora MySQL" TargetDestinationAuroraPostgresql TargetDestination = "Aurora PostgreSQL" TargetDestinationAmazonRdsMysql TargetDestination = "Amazon Relational Database Service on MySQL" TargetDestinationAmazonRdsPostgresql TargetDestination = "Amazon Relational Database Service on PostgreSQL" TargetDestinationAmazonDocumentdb TargetDestination = "Amazon DocumentDB" TargetDestinationAmazonDynamodb TargetDestination = "Amazon DynamoDB" TargetDestinationAmazonRds TargetDestination = "Amazon Relational Database Service" )
Enum values for TargetDestination
func (TargetDestination) Values ¶
func (TargetDestination) Values() []TargetDestination
Values returns all known values for TargetDestination. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type ThrottlingException ¶
type ThrottlingException struct {
Message *string
// contains filtered or unexported fields
}
The request was denied due to request throttling.
func (*ThrottlingException) Error ¶
func (e *ThrottlingException) Error() string
func (*ThrottlingException) ErrorCode ¶
func (e *ThrottlingException) ErrorCode() string
func (*ThrottlingException) ErrorFault ¶
func (e *ThrottlingException) ErrorFault() smithy.ErrorFault
func (*ThrottlingException) ErrorMessage ¶
func (e *ThrottlingException) ErrorMessage() string
type TransformationTool ¶
type TransformationTool struct {
// Description of the tool.
Description *string
// Name of the tool.
Name TransformationToolName
// URL for installing the tool.
TranformationToolInstallationLink *string
// contains filtered or unexported fields
}
Information of the transformation tool that can be used to migrate and modernize the application.
type TransformationToolName ¶
type TransformationToolName string
const ( TransformationToolNameApp2container TransformationToolName = "App2Container" TransformationToolNamePortingAssistant TransformationToolName = "Porting Assistant For .NET" TransformationToolNameEmp TransformationToolName = "End of Support Migration" TransformationToolNameWwama TransformationToolName = "Windows Web Application Migration Assistant" TransformationToolNameMgn TransformationToolName = "Application Migration Service" TransformationToolNameStrategyRecommendationSupport TransformationToolName = "Strategy Recommendation Support" TransformationToolNameInPlaceOsUpgrade TransformationToolName = "In Place Operating System Upgrade" TransformationToolNameSct TransformationToolName = "Schema Conversion Tool" TransformationToolNameDms TransformationToolName = "Database Migration Service" TransformationToolNameNativeSql TransformationToolName = "Native SQL Server Backup/Restore" )
Enum values for TransformationToolName
func (TransformationToolName) Values ¶
func (TransformationToolName) Values() []TransformationToolName
Values returns all known values for TransformationToolName. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.
type UnknownUnionMember ¶
type UnknownUnionMember struct {
Tag string
Value []byte
// contains filtered or unexported fields
}
UnknownUnionMember is returned when a union member is returned over the wire, but has an unknown tag.
type ValidationException ¶
type ValidationException struct {
Message *string
// contains filtered or unexported fields
}
The request body isn't valid.
func (*ValidationException) Error ¶
func (e *ValidationException) Error() string
func (*ValidationException) ErrorCode ¶
func (e *ValidationException) ErrorCode() string
func (*ValidationException) ErrorFault ¶
func (e *ValidationException) ErrorFault() smithy.ErrorFault
func (*ValidationException) ErrorMessage ¶
func (e *ValidationException) ErrorMessage() string
type VersionControl ¶
type VersionControl string
const ( VersionControlGithub VersionControl = "GITHUB" VersionControlGithubEnterprise VersionControl = "GITHUB_ENTERPRISE" )
Enum values for VersionControl
func (VersionControl) Values ¶
func (VersionControl) Values() []VersionControl
Values returns all known values for VersionControl. Note that this can be expanded in the future, and so it is only as up to date as the client. The ordering of this slice is not guaranteed to be stable across updates.