Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Event ¶
type Event struct {
// The type of event, such as click or download. This property corresponds to the
// EVENT_TYPE field of your Interactions schema and depends on the types of events
// you are tracking.
//
// This member is required.
EventType *string
// The timestamp (in Unix time) on the client side when the event occurred.
//
// This member is required.
SentAt *time.Time
// An ID associated with the event. If an event ID is not provided, Amazon
// Personalize generates a unique ID for the event. An event ID is not used as an
// input to the model. Amazon Personalize uses the event ID to distinquish unique
// events. Any subsequent events after the first with the same event ID are not
// used in model training.
EventId *string
// The event value that corresponds to the EVENT_VALUE field of the Interactions
// schema.
EventValue *float32
// A list of item IDs that represents the sequence of items you have shown the
// user. For example, ["itemId1", "itemId2", "itemId3"].
Impression []string
// The item ID key that corresponds to the ITEM_ID field of the Interactions
// schema.
ItemId *string
// A string map of event-specific data that you might choose to record. For
// example, if a user rates a movie on your site, other than movie ID (itemId) and
// rating (eventValue) , you might also send the number of movie ratings made by
// the user. Each item in the map consists of a key-value pair. For example,
// {"numberOfRatings": "12"} The keys use camel case names that match the fields in
// the Interactions schema. In the above example, the numberOfRatings would match
// the 'NUMBER_OF_RATINGS' field defined in the Interactions schema.
//
// This value conforms to the media type: application/json
Properties *string
// The ID of the recommendation.
RecommendationId *string
// contains filtered or unexported fields
}
Represents user interaction event information sent using the PutEvents API.
type InvalidInputException ¶
type InvalidInputException struct {
Message *string
// contains filtered or unexported fields
}
Provide a valid value for the field or parameter.
func (*InvalidInputException) Error ¶
func (e *InvalidInputException) Error() string
func (*InvalidInputException) ErrorCode ¶
func (e *InvalidInputException) ErrorCode() string
func (*InvalidInputException) ErrorFault ¶
func (e *InvalidInputException) ErrorFault() smithy.ErrorFault
func (*InvalidInputException) ErrorMessage ¶
func (e *InvalidInputException) ErrorMessage() string
type Item ¶ added in v0.29.0
type Item struct {
// The ID associated with the item.
//
// This member is required.
ItemId *string
// A string map of item-specific metadata. Each element in the map consists of a
// key-value pair. For example, {"numberOfRatings": "12"}. The keys use camel case
// names that match the fields in the schema for the Items dataset. In the previous
// example, the numberOfRatings matches the 'NUMBER_OF_RATINGS' field defined in
// the Items schema. For categorical string data, to include multiple categories
// for a single item, separate each category with a pipe separator (|). For
// example, \"Horror|Action\".
//
// This value conforms to the media type: application/json
Properties *string
// contains filtered or unexported fields
}
Represents item metadata added to an Items dataset using the PutItems API. For more information see Importing Items Incrementally (https://docs.aws.amazon.com/personalize/latest/dg/importing-items.html).
type ResourceInUseException ¶ added in v1.2.0
type ResourceInUseException struct {
Message *string
// contains filtered or unexported fields
}
The specified resource is in use.
func (*ResourceInUseException) Error ¶ added in v1.2.0
func (e *ResourceInUseException) Error() string
func (*ResourceInUseException) ErrorCode ¶ added in v1.2.0
func (e *ResourceInUseException) ErrorCode() string
func (*ResourceInUseException) ErrorFault ¶ added in v1.2.0
func (e *ResourceInUseException) ErrorFault() smithy.ErrorFault
func (*ResourceInUseException) ErrorMessage ¶ added in v1.2.0
func (e *ResourceInUseException) ErrorMessage() string
type ResourceNotFoundException ¶ added in v0.29.0
type ResourceNotFoundException struct {
Message *string
// contains filtered or unexported fields
}
Could not find the specified resource.
func (*ResourceNotFoundException) Error ¶ added in v0.29.0
func (e *ResourceNotFoundException) Error() string
func (*ResourceNotFoundException) ErrorCode ¶ added in v0.29.0
func (e *ResourceNotFoundException) ErrorCode() string
func (*ResourceNotFoundException) ErrorFault ¶ added in v0.29.0
func (e *ResourceNotFoundException) ErrorFault() smithy.ErrorFault
func (*ResourceNotFoundException) ErrorMessage ¶ added in v0.29.0
func (e *ResourceNotFoundException) ErrorMessage() string
type User ¶ added in v0.29.0
type User struct {
// The ID associated with the user.
//
// This member is required.
UserId *string
// A string map of user-specific metadata. Each element in the map consists of a
// key-value pair. For example, {"numberOfVideosWatched": "45"}. The keys use camel
// case names that match the fields in the schema for the Users dataset. In the
// previous example, the numberOfVideosWatched matches the
// 'NUMBER_OF_VIDEOS_WATCHED' field defined in the Users schema. For categorical
// string data, to include multiple categories for a single user, separate each
// category with a pipe separator (|). For example, \"Member|Frequent shopper\".
//
// This value conforms to the media type: application/json
Properties *string
// contains filtered or unexported fields
}
Represents user metadata added to a Users dataset using the PutUsers API. For more information see Importing Users Incrementally (https://docs.aws.amazon.com/personalize/latest/dg/importing-users.html).
Click to show internal directories.
Click to hide internal directories.